@@ -12,16 +12,16 @@ from taurus.qt.qtgui.input import TaurusValueLineEdit, TaurusValueSpinBox, Tauru
 
 w1 = TaurusLabel()
 w2 = TaurusLabel()
-w3 = TaurusValueLineEdit() # or TaurusValueSpinBox or TaurusWheelEdit
+w3 = TaurusValueLineEdit()  # or TaurusValueSpinBox or TaurusWheelEdit
 w4 = TaurusLabel()
 layout.addWidget(w1)
 layout.addWidget(w2)
 layout.addWidget(w3)
 layout.addWidget(w4)
-w1.model, w1.bgRole = 'sys/tg_test/1/double_scalar?configuration=label', ''
+w1.model, w1.bgRole = 'sys/tg_test/1/double_scalar#label', ''
 w2.model = 'sys/tg_test/1/double_scalar'
 w3.model = 'sys/tg_test/1/double_scalar'
-w4.model, w4.bgRole = 'sys/tg_test/1/double_scalar?configuration=unit', ''
+w4.model, w4.bgRole = 'sys/tg_test/1/double_scalar#unit', ''
 
 panel.show()
-sys.exit(app.exec_())
\ No newline at end of file
+sys.exit(app.exec_())
