@@ -13,9 +13,9 @@ w1, w2, w3 = TaurusLabel(), TaurusLabel(), TaurusLabel()
 layout.addWidget(w1)
 layout.addWidget(w2)
 layout.addWidget(w3)
-w1.model, w1.bgRole = 'sys/tg_test/1/double_scalar?configuration=label', ''
+w1.model, w1.bgRole = 'sys/tg_test/1/double_scalar#label', ''
 w2.model = 'sys/tg_test/1/double_scalar'
-w3.model, w3.bgRole = 'sys/tg_test/1/double_scalar?configuration=unit', ''
+w3.model, w3.bgRole = 'sys/tg_test/1/double_scalar#unit', ''
 
 panel.show()
-sys.exit(app.exec_())
\ No newline at end of file
+sys.exit(app.exec_())
