@@ -2,32 +2,32 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
 """
-event.py: 
+event.py:
 """
 
-__all__ = ["BoundMethodWeakref", "CallableRef", "EventGenerator", 
+__all__ = ["BoundMethodWeakref", "CallableRef", "EventGenerator",
            "ConfigEventGenerator", "ListEventGenerator", "EventListener",
            "AttributeEventWait", "AttributeEventIterator"]
 
@@ -41,13 +41,14 @@ import operator
 
 import taurus.core
 
+
 class BoundMethodWeakref(object):
     """This class represents a weak reference to a method of an object since
     weak references to methods don't work by themselves"""
-    
+
     def __init__(self, bound_method, del_cb=None):
         cb = (del_cb and self._deleted)
-        self.func_ref = weakref.ref(bound_method.im_func, cb) 
+        self.func_ref = weakref.ref(bound_method.im_func, cb)
         self.obj_ref = weakref.ref(bound_method.im_self, cb)
         if cb:
             self.del_cb = CallableRef(del_cb)
@@ -55,11 +56,11 @@ class BoundMethodWeakref(object):
 
     def _deleted(self, obj):
         if not self.already_deleted:
-            del_cb=self.del_cb()
+            del_cb = self.del_cb()
             if del_cb is not None:
                 del_cb(self)
                 self.already_deleted = 1
-        
+
     def __call__(self):
         obj = self.obj_ref()
         if obj is not None:
@@ -81,16 +82,16 @@ class BoundMethodWeakref(object):
         obj, func = self.obj_ref(), self.func_ref()
         return 'BoundMethodWeakRef of %s.%s' % (obj, func)
 
-    
+
 def CallableRef(object, del_cb=None):
-    """This function returns a callable weak reference to a callable object. 
+    """This function returns a callable weak reference to a callable object.
     Object can be a callable object, a function or a method.
-    
+
     :param object: a callable object
     :type object: callable object
     :param del_cb: calback function. Default is None meaning to callback.
     :type del_cb: callable object or None
-    
+
     :return: a weak reference for the given callable
     :rtype: BoundMethodWeakref or weakref.ref"""
     if hasattr(object, 'im_self'):
@@ -101,7 +102,7 @@ def CallableRef(object, del_cb=None):
 
 class EventStack(object):
     "internal usage event stack"
-    
+
     def __init__(self, history=True):
         self.unread_stack = []
         self.read_stack = []
@@ -120,14 +121,14 @@ class EventStack(object):
         del self.unread_stack[0]
         if self.history:
             self.read_stack.append(event)
-        
+
         return event
 
     def getAllUnread(self):
         unread = self.unread_stack
         self.unread_stack = []
         return unread
-    
+
     def getAllRead(self):
         read = self.read_stack
         self.read_stack = []
@@ -136,14 +137,15 @@ class EventStack(object):
 
 from object import Object
 
+
 class EventGenerator(Object):
     """Base class capable of firing events"""
 
     WaitTimeout = 0.1
-    
+
     def __init__(self, name, events_active=True):
         """Event generator constructor.
-        
+
         :param name: the event generator name
         :type  name: str
         :param events_active: generate events (default is True)
@@ -158,7 +160,7 @@ class EventGenerator(Object):
         self.events_active = events_active
         self.cond = threading.Condition()
         self.wait_list = []
-        
+
     def lock(self):
         """Locks this event generator"""
         self.cond.acquire()
@@ -172,23 +174,23 @@ class EventGenerator(Object):
 
     def subscribeEvent(self, cb, data=None):
         """Subscribes to the event
-        
+
         :param cb: a callable object
         :type  cb: callable
         :param data: extra data to send each time an event is triggered on the
                      given callback. Default is None
         :type  data: object"""
         if not self.events_active:
-            raise RuntimeError, ('%s does not have ' \
+            raise RuntimeError, ('%s does not have '
                                  'events/polling active' % self.event_name)
-        
+
         cb_ref = CallableRef(cb, self.unsubscribeDeletedEvent)
 
         try:
             self.lock()
             if (cb_ref, data) in self.cb_list:
                 raise RuntimeError, ('Callback %s(%s) already reg. on %s' %
-                                    (cb, data, self.event_name))
+                                     (cb, data, self.event_name))
             self.cb_list.append((cb_ref, data))
             cb(data, self.first_event_val)
         finally:
@@ -205,11 +207,11 @@ class EventGenerator(Object):
                     del self.cb_list[i]
         finally:
             self.unlock()
-                
+
     def unsubscribeEvent(self, cb, data=None):
         """Unsubscribes the given callback from the event. If the callback is not
         a listener for this event a debug message is generated an nothing happens.
-        
+
         :param cb: a callable object
         :type  cb: callable
         :param data: extra data to send each time an event is triggered on the
@@ -221,10 +223,11 @@ class EventGenerator(Object):
             if (cb_ref, data) in self.cb_list:
                 self.cb_list.remove((cb_ref, data))
             else:
-                self.debug("Trying to unsubscribe: %s is not a listener of %s" % (str(cb_ref),self.event_name))
+                self.debug("Trying to unsubscribe: %s is not a listener of %s" % (
+                    str(cb_ref), self.event_name))
         finally:
             self.unlock()
-    
+
     def isSubscribed(self, cb, data=None):
         """Determines if the given callback is registered for this event.
 
@@ -237,10 +240,10 @@ class EventGenerator(Object):
         :rtype: bool"""
         cb_ref = CallableRef(cb, self.unsubscribeDeletedEvent)
         return (cb_ref, data) in self.cb_list
-         
+
     def setEventsActive(self, events_active):
         """(De)activates events on this event generator.
-        
+
         :param events_active: activate/deactivate events
         :type  events_active: bool"""
         self.events_active = events_active
@@ -250,7 +253,7 @@ class EventGenerator(Object):
         :return: True if events are active or False otherwise
         :rtype: bool"""
         return self.events_active
-    
+
     def fireEvent(self, val, event_val=None):
         """Fires an event.
         :param val: event value
@@ -270,11 +273,11 @@ class EventGenerator(Object):
                     cb(data, event_val)
         finally:
             self.unlock()
-            
+
     def waitEvent(self, val=None, equal=True, any=False, timeout=None,
                   stack=None):
         """Waits for an event to occur
-        
+
         :param val: event value
         :type  val: object
         :param equal: check for equality. Default is True
@@ -289,7 +292,7 @@ class EventGenerator(Object):
         :return: the value of the event that unblocked the wait
         :rtype: object"""
         if not self.events_active:
-            raise RuntimeError, ('%s does not have ' \
+            raise RuntimeError, ('%s does not have '
                                  'events/polling active' % self.event_name)
         try:
             self.lock()
@@ -304,7 +307,7 @@ class EventGenerator(Object):
                 if any:
                     block = not avail
                 else:
-                    block = ((equal and (val != curr_val)) or \
+                    block = ((equal and (val != curr_val)) or
                              (not equal and (val == curr_val)))
                 if timeout:
                     timeout_expired = (time.time() - t0 > timeout)
@@ -321,7 +324,7 @@ class EventGenerator(Object):
 
     def read(self):
         """Read the last event
-        
+
         :return: the last event value
         :rtype: object"""
         return self.last_val
@@ -329,7 +332,7 @@ class EventGenerator(Object):
 
 class EventListener(object):
     """A class that listens for an event with a specific value
-    
+
     Note: Since this class stores for each event value the last timestamp when
     it occured, it should only be used for events for which the event value
     domain (possible values) is limited and well known (ex: an enum)"""
@@ -337,12 +340,12 @@ class EventListener(object):
     def __init__(self):
         self.last_val = None
         self.cond = threading.Condition()
-        
+
         # a set implemented as a dictionary
         # dict<object, float>
         # key - event value
         # value - timestamp of last event with that value
-        self.event_set = {} 
+        self.event_set = {}
         self.attr.addListener(self)
 
     def lock(self):
@@ -364,7 +367,7 @@ class EventListener(object):
         """Notifies that a given event has arrived
         This function is protected inside with the object's lock. Do NOT call
         this function when you have the lock acquired on this object.
-        
+
         :param v: event value
         :type  v: object"""
         try:
@@ -378,15 +381,15 @@ class EventListener(object):
 
     def waitEvent(self, val, after=0, equal=True):
         """Wait for an event with the given value. You MUST protect this function
-        with this object's lock before calling this method and always unlock it 
+        with this object's lock before calling this method and always unlock it
         afterward, of course::
-        
+
             from taurus.core.util.event import EventListener
-            
+
             class MyEvtListener(EventListener):
                 # Your specific listener code here
                 pass
-            
+
             evt_listener = EventListener()
             try:
                 evt_listener.lock()
@@ -395,13 +398,13 @@ class EventListener(object):
                 evt_listener.waitEvent(Stop, t)
             finally:
                 evt_listener.unlock()
-        
+
         :param val: value to compare
         :type  val: object
         :param after: timestamp. wait for events comming after the given time.
                       default value is 0 meaning any event after Jan 1, 1970
         :type  after: float
-        :param equal: compare for equality. equal=True means an event with the 
+        :param equal: compare for equality. equal=True means an event with the
                       given value, equal=False means any event which as a different value
         :type  equal: bool
         """
@@ -409,11 +412,14 @@ class EventListener(object):
         while True:
             if equal:
                 t = s.get(val)
-                if t and t >= after: return
+                if t and t >= after:
+                    return
             else:
                 for v, t in s.items():
-                    if v == val: continue
-                    if t >= after: return
+                    if v == val:
+                        continue
+                    if t >= after:
+                        return
             self.cond.wait()
 
 
@@ -422,7 +428,7 @@ class ConfigEventGenerator(EventGenerator):
 
     def fireEvent(self, val, event_val=None):
         EventGenerator.fireEvent(self, val, event_val)
-        
+
 
 class ListEventGenerator(EventGenerator):
     """Manage list events, detecting changes in the list"""
@@ -431,12 +437,12 @@ class ListEventGenerator(EventGenerator):
         self.call__init__(EventGenerator, name, events_active)
         self.last_val = []
         self.first_event_val = [], [], []
-        
+
     def fireEvent(self, val):
         """Notifies that a given event has arrived
         This function is protected inside with the object's lock. Do NOT call
         this function when you have the lock acquired on this object.
-        
+
         :param val: event value
         :type  val: object"""
         # if attribute is not alive and last time was also not alive then
@@ -445,13 +451,13 @@ class ListEventGenerator(EventGenerator):
             if len(self.last_val) == 0:
                 return
             val = []
-            
+
         try:
             self.lock()
             val = list(val)
             last_val = self.last_val
-            rm  = [x for x in last_val if x not in val]
-            add  = [x for x in val if x not in last_val]
+            rm = [x for x in last_val if x not in val]
+            add = [x for x in val if x not in last_val]
             event_val = val, rm, add
             EventGenerator.fireEvent(self, val, event_val)
             self.first_event_val = val, [], val
@@ -470,7 +476,7 @@ class AttributeEventWait(object):
         self._event_set = {}
         if attr is not None:
             self.connect(attr)
-    
+
     def connect(self, attr):
         """Connect to the given attribute
         :param attr: the attribute to connect to
@@ -479,11 +485,13 @@ class AttributeEventWait(object):
         if self._attr is not None:
             if attr == self._attr:
                 needAdd = False
-            else: self._attr.removeListener(self)
+            else:
+                self._attr.removeListener(self)
         self.clearEventSet()
         self._last_val = None
         self._attr = attr
-        if needAdd: self._attr.addListener(self)
+        if needAdd:
+            self._attr.addListener(self)
 
     def disconnect(self):
         """Disconnects from the attribute. If not connected nothing happens."""
@@ -527,12 +535,12 @@ class AttributeEventWait(object):
             self.fireEvent(None)
         else:
             self.fireEvent(v.value)
-        
+
     def fireEvent(self, v):
         """Notifies that a given event has arrived
         This function is protected inside with the object's lock. Do NOT call
         this function when you have the lock acquired on this object.
-        
+
         :param v: event value
         :type  v: object"""
         t = time.time()
@@ -543,49 +551,49 @@ class AttributeEventWait(object):
             self._cond.notifyAll()
         finally:
             self.unlock()
-    
+
     def getLastRecordedEvent(self):
         """returns the value of the last recorded event or None if no event has
         been received or the last event was an error event
-        
+
         :return: the last event value to be recorded
         :rtype: object"""
         return self._last_val
-    
+
     def getRecordedEvents(self):
         """Returns a reference to the internal dictionary used to store the internal
         events. Modify the return dictionary at your own risk!
-        
+
         :return: reference to the internal event dictionary
         :rtype: dict"""
         return self._event_set
-    
+
     def getRecordedEvent(self, v):
         """Returns the the recorded local timestamp for the event with the given
         value or None if no event with the given value has been recorded.
-        
+
         :param v: event value
         :type  v: object
         :return: local timestamp for the event or None if no event has been recorded
         :rtype: float"""
         return self._event_set.get(v)
-    
+
     def waitEvent(self, val, after=0, equal=True, timeout=None, retries=-1,
                   any=False):
         """Wait for an event with the given value.
-        
+
         :param val: value to compare
         :type  val: object
         :param after: timestamp. wait for events comming after the given time.
                       default value is 0 meaning any event after Jan 1, 1970
         :type  after: float
-        :param equal: compare for equality. equal=True means an event with the 
+        :param equal: compare for equality. equal=True means an event with the
                       given value, equal=False means any event which as a different value
         :type  equal: bool
         :param timeout: maximum time to wait (seconds). Default is None meaning
                wait forever.
         :type  timeout: float
-        :param retries: number of maximum retries of max timeout to attempts. 
+        :param retries: number of maximum retries of max timeout to attempts.
                         Default is -1 meaning infinite number of retries.
                         0 means no wait. Positive number is obvious.
         :param any: if any is True ignore 'val' parameter and accept any event.
@@ -608,19 +616,23 @@ class AttributeEventWait(object):
             while retries != 0:
                 if any:
                     for v, t in s.items():
-                        if t >= after: return
+                        if t >= after:
+                            return
                 if equal:
                     t = s.get(val)
                     if (t is not None) and (t >= after):
                         return
                 else:
                     for v, t in s.items():
-                        if v == val: continue
-                        if t >= after: return
+                        if v == val:
+                            continue
+                        if t >= after:
+                            return
                 self._cond.wait(timeout)
                 retries -= 1
         except Exception, e:
-            sys.stderr.write("AttributeEventWait: Caught exception while waitting: %s\n" % str(e))
+            sys.stderr.write(
+                "AttributeEventWait: Caught exception while waitting: %s\n" % str(e))
             raise e
         finally:
             self.unlock()
@@ -634,7 +646,7 @@ class AttributeEventIterator(object):
         self._cond = threading.Condition()
         if len(attrs) > 0:
             self.connect(attrs)
-    
+
     def connect(self, attrs):
         if not operator.isSequenceType(attrs):
             attrs = (attrs,)
@@ -642,15 +654,16 @@ class AttributeEventIterator(object):
         self._attrs = attrs
         for attr in self._attrs:
             attr.addListener(self)
-    
+
     def disconnect(self):
-        if self._attrs is None: return
+        if self._attrs is None:
+            return
         for attr in self._attrs:
             attr.removeListener(self)
-    
+
     def lock(self):
         self._cond.acquire()
-    
+
     def unlock(self):
         if self._cond._is_owned():
             self._cond.release()
@@ -660,12 +673,12 @@ class AttributeEventIterator(object):
             curr_th = threading.current_thread()
             print "WARNING: Thread %s trying to unlock condition previously " \
                   "locked by thread %s" % (curr_th.name, th.name)
-    
+
     def eventReceived(self, s, t, v):
         if t not in (taurus.core.taurusbasetypes.TaurusEventType.Change, taurus.core.taurusbasetypes.TaurusEventType.Periodic):
             return
         self.fireEvent(s, v.value)
-    
+
     def fireEvent(self, s, v):
         t = time.time()
         self.lock()
@@ -684,4 +697,4 @@ class AttributeEventIterator(object):
         except Exception, e:
             print "INFO: Caught exception while waiting", str(e)
         finally:
-            self.unlock()
\ No newline at end of file
+            self.unlock()
