@@ -2,24 +2,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -32,15 +32,16 @@ import operator
 import re
 import math
 
+
 def indent(rows, hasHeader=False, headerChar='-', delim=' | ', justify='left',
-           separateRows=False, prefix='', postfix='', wrapfunc=lambda x:x):
+           separateRows=False, prefix='', postfix='', wrapfunc=lambda x: x):
     """Indents a table by column.
        - rows: A sequence of sequences of items, one sequence per row.
        - hasHeader: True if the first row consists of the columns' names.
        - headerChar: Character to be used for the row separator line
          (if hasHeader==True or separateRows==True).
        - delim: The column delimiter.
-       - justify: Determines how are data justified in their column. 
+       - justify: Determines how are data justified in their column.
          Valid values are 'left','right' and 'center'.
        - separateRows: True if rows are to be separated by a line
          of 'headerChar's.
@@ -48,47 +49,53 @@ def indent(rows, hasHeader=False, headerChar='-', delim=' | ', justify='left',
        - postfix: A string appended to each printed row.
        - wrapfunc: A function f(text) for wrapping text; each element in
          the table is first wrapped by this function.
-         
+
         Returns a list of strings. One for each row of the table
     """
-    
+
     # closure for breaking logical rows to physical, using wrapfunc
     def rowWrapper(row):
         newRows = [wrapfunc(item).split('\n') for item in row]
-        return [[substr or '' for substr in item] for item in map(None,*newRows)]
+        return [[substr or '' for substr in item] for item in map(None, *newRows)]
 
     # break each logical row into one or more physical ones
     logicalRows = [rowWrapper(row) for row in rows]
     # columns of physical rows
-    
-    columns = map(None,*reduce(operator.add,logicalRows))
-    
+
+    columns = map(None, *reduce(operator.add, logicalRows))
+
     # get the maximum of each column by the string length of its items
-    maxWidths = [max([len(str(item)) for item in column]) for column in columns]
-    if separateRows or hasHeader: 
-        rowSeparator = headerChar * (len(prefix) + len(postfix) + sum(maxWidths) + \
-                                     len(delim)*(len(maxWidths)-1))
-    else: 
+    maxWidths = [max([len(str(item)) for item in column])
+                 for column in columns]
+    if separateRows or hasHeader:
+        rowSeparator = headerChar * (len(prefix) + len(postfix) + sum(maxWidths) +
+                                     len(delim) * (len(maxWidths) - 1))
+    else:
         rowSeparator = "<ERR>"
-        
+
     # select the appropriate justify method
-    justify = {'center':str.center, 'right':str.rjust, 'left':str.ljust}[justify.lower()]
-    
+    justify = {'center': str.center, 'right': str.rjust,
+               'left': str.ljust}[justify.lower()]
+
     output = []
-    if separateRows: output.append(rowSeparator)
+    if separateRows:
+        output.append(rowSeparator)
     for physicalRows in logicalRows:
         for row in physicalRows:
-            line =  prefix
-            line += delim.join([justify(str(item),width) for (item,width) in zip(row,maxWidths)])
+            line = prefix
+            line += delim.join([justify(str(item), width)
+                                for (item, width) in zip(row, maxWidths)])
             line += postfix
             output.append(line)
-        if separateRows or hasHeader: 
+        if separateRows or hasHeader:
             output.append(rowSeparator)
-            hasHeader=False
+            hasHeader = False
     return output
 
 # written by Mike Brown
 # http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/148061
+
+
 def wrap_onspace(text, width):
     """
     A word-wrap function that preserves existing line breaks
@@ -97,58 +104,62 @@ def wrap_onspace(text, width):
     """
     return reduce(lambda line, word, width=width: '%s%s%s' %
                   (line,
-                   ' \n'[(len(line[line.rfind('\n')+1:])
-                         + len(word.split('\n',1)[0]
-                              ) >= width)],
+                   ' \n'[(len(line[line.rfind('\n') + 1:])
+                          + len(word.split('\n', 1)[0]
+                                ) >= width)],
                    word),
                   text.split(' ')
-                 )
+                  )
 
 
 def wrap_onspace_strict(text, width):
     """Similar to wrap_onspace, but enforces the width constraint:
        words longer than width are split."""
-    wordRegex = re.compile(r'\S{'+str(width)+r',}')
-    return wrap_onspace(wordRegex.sub(lambda m: wrap_always(m.group(),width),text),width)
+    wordRegex = re.compile(r'\S{' + str(width) + r',}')
+    return wrap_onspace(wordRegex.sub(lambda m: wrap_always(m.group(), width), text), width)
 
 import math
+
+
 def wrap_always(text, width):
     """A simple word-wrap function that wraps text on exactly width characters.
        It doesn't split the text in words."""
-    return '\n'.join([ text[width*i:width*(i+1)] \
-                       for i in xrange(int(math.ceil(1.*len(text)/width))) ])
-    
+    return '\n'.join([text[width * i:width * (i + 1)]
+                      for i in xrange(int(math.ceil(1. * len(text) / width)))])
+
 if __name__ == '__main__':
     labels = ('First Name', 'Last Name', 'Age', 'Position')
     data = \
-    '''John,Smith,24,Software Engineer
+        '''John,Smith,24,Software Engineer
        Mary,Brohowski,23,Sales Manager
        Aristidis,Papageorgopoulos,28,Senior Reseacher'''
-    rows = [row.strip().split(',')  for row in data.splitlines()]
+    rows = [row.strip().split(',') for row in data.splitlines()]
 
     print 'Without wrapping function\n'
-    for l in indent([labels]+rows, hasHeader=True): print l
-    
+    for l in indent([labels] + rows, hasHeader=True):
+        print l
+
     # test indent with different wrapping functions
     width = 10
-    for wrapper in (wrap_always,wrap_onspace,wrap_onspace_strict):
-        print 'Wrapping function: %s(x,width=%d)\n' % (wrapper.__name__,width)
-        o = indent([labels]+rows, headerChar='=', hasHeader=True, separateRows=False,
+    for wrapper in (wrap_always, wrap_onspace, wrap_onspace_strict):
+        print 'Wrapping function: %s(x,width=%d)\n' % (wrapper.__name__, width)
+        o = indent([labels] + rows, headerChar='=', hasHeader=True, separateRows=False,
                    prefix='|', postfix='|', delim=' ',
-                   wrapfunc=lambda x: wrapper(x,width))
-        for l in o : print l
-    
+                   wrapfunc=lambda x: wrapper(x, width))
+        for l in o:
+            print l
+
     # output:
     #
-    #Without wrapping function
+    # Without wrapping function
     #
-    #First Name | Last Name        | Age | Position         
+    # First Name | Last Name        | Age | Position
     #-------------------------------------------------------
-    #John       | Smith            | 24  | Software Engineer
-    #Mary       | Brohowski        | 23  | Sales Manager    
-    #Aristidis  | Papageorgopoulos | 28  | Senior Reseacher 
+    # John       | Smith            | 24  | Software Engineer
+    # Mary       | Brohowski        | 23  | Sales Manager
+    # Aristidis  | Papageorgopoulos | 28  | Senior Reseacher
     #
-    #Wrapping function: wrap_always(x,width=10)
+    # Wrapping function: wrap_always(x,width=10)
     #
     #----------------------------------------------
     #| First Name | Last Name  | Age | Position   |
@@ -163,7 +174,7 @@ if __name__ == '__main__':
     #|            | poulos     |     | eacher     |
     #----------------------------------------------
     #
-    #Wrapping function: wrap_onspace(x,width=10)
+    # Wrapping function: wrap_onspace(x,width=10)
     #
     #---------------------------------------------------
     #| First Name | Last Name        | Age | Position  |
@@ -178,7 +189,7 @@ if __name__ == '__main__':
     #|            |                  |     | Reseacher |
     #---------------------------------------------------
     #
-    #Wrapping function: wrap_onspace_strict(x,width=10)
+    # Wrapping function: wrap_onspace_strict(x,width=10)
     #
     #---------------------------------------------
     #| First Name | Last Name  | Age | Position  |
