@@ -2,24 +2,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -40,9 +40,9 @@ from log import Logger, DebugIt, TraceIt
 
 class ThreadPool(Logger):
     """"""
-    
-    NoJob = 6*(None,)
-    
+
+    NoJob = 6 * (None,)
+
     def __init__(self, name=None, parent=None, Psize=20, Qsize=20, daemons=True):
         Logger.__init__(self, name, parent)
         self._daemons = daemons
@@ -59,7 +59,7 @@ class ThreadPool(Logger):
             nb_workers = len(self.workers)
             if newSize == nb_workers:
                 return
-            
+
             for i in range(newSize - nb_workers):
                 self.localThreadId += 1
                 name = "%s.W%03i" % (self.log_name, self.localThreadId)
@@ -67,37 +67,38 @@ class ThreadPool(Logger):
                 self.workers.append(new)
                 self.debug("Starting %s" % name)
                 new.start()
-            
+
             # remove the old worker threads
             nb_workers = len(self.workers)
             for i in range(nb_workers - newSize):
                 self.jobs.put(self.NoJob)
-                
+
         def get(self):
             """get method for the size property"""
             return len(self.workers)
-        
+
         return get, set, None, "number of threads"
-    
+
     def add(self, job, callback=None, *args, **kw):
         if self.accept:
             # first gather some information on the object which requested the
             # job in case the job throws an exception
             th_id, stack = currentThread().name, extract_stack()[:-1]
             self.jobs.put((job, args, kw, callback, th_id, stack))
-            
+
     def join(self):
-        self.accept=False
+        self.accept = False
         while True:
             for w in self.workers:
-                if w.isAlive() :
+                if w.isAlive():
                     self.jobs.put(self.NoJob)
                     break
             else:
                 break
 
     @property
-    def qsize(self): return self.jobs.qsize()
+    def qsize(self):
+        return self.jobs.qsize()
 
     def getNumOfBusyWorkers(self):
         ''' Get the number of workers that are in busy mode.
@@ -110,16 +111,16 @@ class ThreadPool(Logger):
 
 
 class Worker(Thread, Logger):
-    
+
     def __init__(self, pool, name=None, daemon=True):
         name = name or self.__class__.__name__
         Thread.__init__(self, name=name)
         Logger.__init__(self, name, pool)
         self.daemon = daemon
         self.pool = pool
-        self.cmd=''
+        self.cmd = ''
         self.busy = False
-    
+
     def run(self):
         get = self.pool.jobs.get
         while True:
@@ -147,21 +148,24 @@ class Worker(Thread, Logger):
     def isBusy(self):
         return self.busy
 
-if __name__=='__main__':
+if __name__ == '__main__':
 
     def easyJob(*arg, **kw):
-        n=arg[0]
+        n = arg[0]
         print '\tSleep\t\t', n
         sleep(n)
         return 'Slept\t%d' % n
+
     def longJob(*arg, **kw):
         print "\tStart\t\t\t", arg, kw
-        n=arg[0]*3
+        n = arg[0] * 3
         sleep(n)
         return "Job done in %d" % n
+
     def badJob(*a, **k):
         print '\n !!! OOOPS !!!\n'
-        a=1/0
+        a = 1 / 0
+
     def show(*arg, **kw):
         print 'callback : %s' % arg[0]
 
@@ -171,7 +175,8 @@ if __name__=='__main__':
         pool = ThreadPool(name='ThreadPool', Psize=workers, Qsize=jobqueue)
         print "\n\t\t... let's add some jobs ...\n"
         for j in range(5):
-            if j==1: pool.add(badJob)
+            if j == 1:
+                pool.add(badJob)
             for i in range(5, 0, -1):
                 pool.add(longJob, show, i)
                 pool.add(easyJob, show, i)
@@ -181,7 +186,7 @@ if __name__=='__main__':
         sleep(15)
         print "\n\t\t... ok, that may take a while, let's get some reinforcement ...\n"
         sleep(5)
-        pool.size=50
+        pool.size = 50
         print '\n\t\t... Joining ...\n'
         pool.join()
         print '\n\t\t... Ok ...\n'
@@ -200,11 +205,11 @@ if __name__=='__main__':
             pool.add(easyJob, None, sleep_t)
         print '\n\t\t... Monitoring the busy workers ...\n'
         t0 = time()
-        while pool.getNumOfBusyWorkers() > 0 :
+        while pool.getNumOfBusyWorkers() > 0:
             print "busy workers = %s" % (pool.getNumOfBusyWorkers())
             sleep(0.5)
         t1 = time()
-        print "Run %s jobs of 1 second took %.3f" % (numjobs, t1-t0)
+        print "Run %s jobs of 1 second took %.3f" % (numjobs, t1 - t0)
         print '\n\t\t... Joining ...\n'
         pool.join()
         print '\n\t\t... Ok ...\n'
