@@ -2,63 +2,89 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
+# This file is part of Taurus
 ##
-## http://www.tango-controls.org/static/tau/latest/doc/html/index.html
+# http://www.tango-controls.org/static/tau/latest/doc/html/index.html
 ##
-## (copyleft) CELLS / ALBA Synchrotron, Bellaterra, Spain
+# (copyleft) CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
-## This is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
+# This is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
 ##
-## This software is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+# This software is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with this program; if not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, see <http://www.gnu.org/licenses/>.
 ###########################################################################
 
 """
 emitter.py: This module provides a task scheduler used by TaurusGrid and TaurusDevTree widgets
 """
 
+import Queue
+import traceback
 from functools import partial
+from collections import Iterable
+
 import taurus
 from taurus.external.qt import Qt
 from taurus.core.util.log import Logger
 from taurus.core.util.singleton import Singleton
-import Queue,traceback
+
+
 
 ###############################################################################
 # Helping methods
 
+
 def isString(seq):
-    if isinstance(seq,basestring): return True # It matches most python str-like classes
-    if any(s in str(type(seq)).lower() for s in ('vector','array','list',)): return False
-    if 'qstring' == str(type(seq)).lower(): return True # It matches QString
+    if isinstance(seq, basestring):
+        return True  # It matches most python str-like classes
+    if any(s in str(type(seq)).lower() for s in ('vector', 'array', 'list',)):
+        return False
+    if 'qstring' == str(type(seq)).lower():
+        return True  # It matches QString
     return False
-    
-def modelSetter(obj,model):
+
+
+def modelSetter(obj, model):
     """
     This class is used for convenience as TaurusEmitterThread standard method
     """
-    #print 'In modelSetter(%s,%s)' % (str(obj),str(model))
-    if hasattr(obj,'setModel') and model is not None: obj.setModel(model)
+    # print 'In modelSetter(%s,%s)' % (str(obj),str(model))
+    if hasattr(obj, 'setModel') and model is not None:
+        obj.setModel(model)
     return
-    
+
+
 class MethodModel(object):
     """
     Class to emulate method execution as a setModel
     """
-    def __init__(self,method): self.method = method
-    def setModel(self,value): return self.method(value)
-    
+
+    def __init__(self, method):
+        self.method = method
+
+    def setModel(self, value):
+        return self.method(value)
+
+
+class QEmitter(Qt.QObject):
+    """Emitter class providing two signals."""
+
+    doSomething = Qt.pyqtSignal(Iterable)
+    somethingDone = Qt.pyqtSignal()
+    newQueue = Qt.pyqtSignal()
+
+
 ###############################################################################
 
+
 class TaurusEmitterThread(Qt.QThread):
     """
     The TaurusEmitterThread Class
@@ -66,7 +92,7 @@ class TaurusEmitterThread(Qt.QThread):
 
     This object get items from a python Queue and performs a thread safe operation on them.
     It is useful to serialize Qt tasks in a background thread.
-    
+
     :param parent: a Qt/Taurus object
     :param name: identifies object logs
     :param queue: if None parent.getQueue() is used, if not then the queue passed as argument is used
@@ -106,11 +132,11 @@ class TaurusEmitterThread(Qt.QThread):
         #Applying TaurusEmitterThread to an existing class:
         import Queue
         from functools import partial
-        
+
         def modelSetter(args):
             obj,model = args[0],args[1]
             obj.setModel(model)
-        
+
         klass TaurusGrid(Qt.QFrame, TaurusBaseWidget):
             ...
             def __init__(self, parent = None, designMode = False):
@@ -126,59 +152,66 @@ class TaurusEmitterThread(Qt.QThread):
                 ...
             def setModel(self,model):
                 ...
-                if hasattr(self,'modelsThread') and not self.modelsThread.isRunning(): 
+                if hasattr(self,'modelsThread') and not self.modelsThread.isRunning():
                     self.modelsThread.start()
                 elif self.modelsQueue.qsize():
                     self.modelsThread.next()
-                ...    
+                ...
 
     """
-    def __init__(self, parent=None,name='',queue=None,method=None,cursor=None,sleep=5000):
+
+    def __init__(self, parent=None, name='', queue=None, method=None, cursor=None, sleep=5000):
         """
         Parent most not be None and must be a TaurusGraphicsScene!
         """
         Qt.QThread.__init__(self, parent)
         self.name = name
-        self.log = Logger('TaurusEmitterThread(%s)'%self.name)
+        self.log = Logger('TaurusEmitterThread(%s)' % self.name)
         self.log.setLogLevel(self.log.Info)
         self.queue = queue or Queue.Queue()
         self.todo = Queue.Queue()
         self.method = method
-        self.cursor = Qt.QCursor(Qt.Qt.WaitCursor) if cursor is True else cursor
+        self.cursor = Qt.QCursor(
+            Qt.Qt.WaitCursor) if cursor is True else cursor
         self._cursor = False
         self.timewait = sleep
-        
-        self.emitter = Qt.QObject()
+
+        self.emitter = QEmitter()
         self.emitter.moveToThread(Qt.QApplication.instance().thread())
-        self.emitter.setParent(Qt.QApplication.instance()) #Mandatory!!! if parent is set before changing thread it could lead to segFaults!
+        # Mandatory!!! if parent is set before changing thread it could lead to
+        # segFaults!
+        self.emitter.setParent(Qt.QApplication.instance())
         self._done = 0
-        #Moved to the end to prevent segfaults ...
-        Qt.QObject.connect(self.emitter, Qt.SIGNAL("doSomething"), self._doSomething)
-        Qt.QObject.connect(self.emitter, Qt.SIGNAL("somethingDone"), self.next) 
-        
+        # Moved to the end to prevent segfaults ...
+        self.emitter.doSomething.connect(self._doSomething)
+        self.emitter.somethingDone.connect(self.next)
+
     def getQueue(self):
-        if self.queue: return self.queue
-        elif hasattr(self.parent(),'getQueue'): self.parent().getQueue()
-        else: return None
+        if self.queue:
+            return self.queue
+        elif hasattr(self.parent(), 'getQueue'):
+            self.parent().getQueue()
+        else:
+            return None
 
     def getDone(self):
         """ Returns % of done tasks in 0-1 range """
-        return self._done/(self._done+self.getQueue().qsize()) if self._done else 0.
-    
+        return self._done / (self._done + self.getQueue().qsize()) if self._done else 0.
+
     def clear(self):
         while not self.todo.empty():
             self.todo.get()
         while not self.getQueue().empty():
             self.getQueue().get()
-            self._done+=1
-            
+            self._done += 1
+
     def purge(obj):
         nqueue = Queue.Queue()
-        while not self.todo.empty(): 
+        while not self.todo.empty():
             i = self.todo.get()
             if obj not in i:
-                nqueue.put(i)        
-        while not self.queue.empty(): 
+                nqueue.put(i)
+        while not self.queue.empty():
             i = self.queue.get()
             if obj not in i:
                 nqueue.put(i)
@@ -186,47 +219,50 @@ class TaurusEmitterThread(Qt.QThread):
             self.queue.put(nqueue.get())
         self.next()
 
-    def _doSomething(self,params):
-        self.log.debug('At TaurusEmitterThread._doSomething(%s)'%str(params))
-        if not self.method: 
-            method,args = params[0],params[1:]
-        else: 
-            method,args = self.method,params
+    def _doSomething(self, params):
+        self.log.debug('At TaurusEmitterThread._doSomething(%s)' % str(params))
+        if not self.method:
+            method, args = params[0], params[1:]
+        else:
+            method, args = self.method, params
         if method:
             try:
                 method(*args)
             except:
-                self.log.error('At TaurusEmitterThread._doSomething(%s): \n%s' % (map(str,args),traceback.format_exc()))
-        self.emitter.emit(Qt.SIGNAL("somethingDone"))
+                self.log.error('At TaurusEmitterThread._doSomething(%s): \n%s' % (
+                    map(str, args), traceback.format_exc()))
+        self.emitter.somethingDone.emit()
         self._done += 1
         return
-                
+
     def next(self):
         queue = self.getQueue()
         msg = 'At TaurusEmitterThread.next(), %d items remaining.' % queue.qsize()
         (queue.empty() and self.log.info or self.log.debug)(msg)
         try:
-            if not queue.empty():            
-                if not self._cursor and self.cursor is not None: 
+            if not queue.empty():
+                if not self._cursor and self.cursor is not None:
                     Qt.QApplication.instance().setOverrideCursor(Qt.QCursor(self.cursor))
-                    self._cursor=True                
-                item = queue.get(False) #A blocking get here would hang the GUIs!!!
+                    self._cursor = True
+                # A blocking get here would hang the GUIs!!!
+                item = queue.get(False)
                 self.todo.put(item)
                 self.log.debug('Item added to todo queue: %s' % str(item))
-            elif self._cursor: 
+            elif self._cursor:
                 Qt.QApplication.instance().restoreOverrideCursor()
-                self._cursor = False        
-                
+                self._cursor = False
+
         except Queue.Empty:
             self.log.warning(traceback.format_exc())
             pass
-        except: 
+        except:
             self.log.warning(traceback.format_exc())
         return
-        
+
     def run(self):
-        Qt.QApplication.instance().thread().sleep(int(self.timewait/1000) if self.timewait>10 else int(self.timewait)) #wait(self.sleep)
-        self.log.info('#'*80)
+        Qt.QApplication.instance().thread().sleep(int(self.timewait / 1000)
+                                                  if self.timewait > 10 else int(self.timewait))  # wait(self.sleep)
+        self.log.info('#' * 80)
         self.log.info('At TaurusEmitterThread.run()')
         self.next()
         while True:
@@ -238,20 +274,22 @@ class TaurusEmitterThread(Qt.QThread):
                 else:
                     continue
             self.log.debug('Emitting doSomething signal ...')
-            self.emitter.emit(Qt.SIGNAL("doSomething"), item)
-            #End of while
-        self.log.info('#'*80+'\nOut of TaurusEmitterThread.run()'+'\n'+'#'*80)
-        #End of Thread 
-        
-class SingletonWorker():#Qt.QObject):
+            self.emitter.doSomething.emit(item)
+            # End of while
+        self.log.info(
+            '#' * 80 + '\nOut of TaurusEmitterThread.run()' + '\n' + '#' * 80)
+        # End of Thread
+
+
+class SingletonWorker():  # Qt.QObject):
     """
     The SingletonWorker works
     =========================
-    
+
     The SingletonWorker class is constructed using the same arguments than the TaurusTreadEmitter class ; but instead of creating a QThread for each instance of the class it creates a single QThread for all instances.
-    
+
     The Queue is still different for each of the instances; it is connected to the TaurusEmitterThread signals (*next()* and *somethingDone()*) and each Worker queue is used as a feed for the shared QThread.
-    
+
     This implementation reduced the cpu of vacca application in a 50% factor.
 
     :param parent: a Qt/Taurus object
@@ -262,89 +300,110 @@ class SingletonWorker():#Qt.QObject):
     This class is used to manage TaurusEmitterThread as Singleton objects:
     """
     _thread = None
-        
-    def __init__(self,parent=None,name='',queue=None,method=None,cursor=None,sleep=5000,log=Logger.Warning,start=True):
+
+    def __init__(self, parent=None, name='', queue=None, method=None, cursor=None, sleep=5000, log=Logger.Warning, start=True):
         self.name = name
-        self.log = Logger('SingletonWorker(%s)'%self.name)
+        self.log = Logger('SingletonWorker(%s)' % self.name)
         self.log.setLogLevel(log)
-        self.log.info('At SingletonWorker.__init__(%s)'%self.name)
+        self.log.info('At SingletonWorker.__init__(%s)' % self.name)
         self.parent = parent
         self.method = method
         self._running = False
         if SingletonWorker._thread is None:
-            SingletonWorker._thread = TaurusEmitterThread(parent,name='SingletonWorker',cursor=cursor,sleep=sleep)
+            SingletonWorker._thread = TaurusEmitterThread(
+                parent, name='SingletonWorker', cursor=cursor, sleep=sleep)
         self.thread = SingletonWorker._thread
         self.queue = queue or Queue.Queue()
-        if start: self.start()
-        
-    def put(self,item,block=True,timeout=None):
-        self.getQueue().put(item,block,timeout)
-        
+        if start:
+            self.start()
+
+    def put(self, item, block=True, timeout=None):
+        self.getQueue().put(item, block, timeout)
+
     def size(self):
         return self.getQueue().qsize()
-        
-    def next(self,item=None):
-        if item is not None: self.put(item)
-        elif self.queue.empty(): return
+
+    def next(self, item=None):
+        if item is not None:
+            self.put(item)
+        elif self.queue.empty():
+            return
         msg = 'At SingletonWorker.next(), %d items not passed yet to Emitter.' % self.queue.qsize()
         self.log.info(msg)
         #(queue.empty() and self.log.info or self.log.debug)(msg)
         try:
             i = 0
             while not self.queue.empty():
-                item = self.queue.get(False) #A blocking get here would hang the GUIs!!!
-                if self.method: 
-                    self.thread.getQueue().put([self.method]+list(item))
+                # A blocking get here would hang the GUIs!!!
+                item = self.queue.get(False)
+                if self.method:
+                    self.thread.getQueue().put([self.method] + list(item))
                 else:
                     self.thread.getQueue().put(item)
-                i+=1
+                i += 1
             self.log.info('%d Items added to emitter queue' % i)
-            self.thread.emitter.emit(Qt.SIGNAL("newQueue"))
+            self.thread.emitter.newQueue.emit()
         except Queue.Empty:
             self.log.warning(traceback.format_exc())
-        except: 
+        except:
             self.log.warning(traceback.format_exc())
         return
-    
-    def getQueue(self): return self.queue
-    def getDone(self): return self.thread.getDone()
-    
-    def start(self): 
-        Qt.QObject.connect(self.thread.emitter, Qt.SIGNAL("somethingDone"), self.next) 
-        Qt.QObject.connect(self.thread.emitter, Qt.SIGNAL("newQueue"), self.thread.next)
-        try: self.thread.start()
-        except: pass
+
+    def getQueue(self):
+        return self.queue
+
+    def getDone(self):
+        return self.thread.getDone()
+
+    def start(self):
+        self.thread.emitter.somethingDone.connect(self.next)
+        self.thread.emitter.newQueue.connect(self.thread.next)
+        try:
+            self.thread.start()
+        except:
+            pass
         self.next()
         self._running = True
         return
-    
-    def stop(self): 
-        Qt.QObject.disconnect(self.thread.emitter, Qt.SIGNAL("somethingDone"), self.next) 
-        Qt.QObject.disconnect(self.thread.emitter, Qt.SIGNAL("newQueue"), self.thread.next)
+
+    def stop(self):
+        self.thread.emitter.somethingDone.disconnect(self.next)
+        self.thread.emitter.newQueue.disconnect(self.thread.next)
         self._running = False
         return
-    
+
     def clear(self):
-        """ 
+        """
         This method will clear queue only if next() has not been called.
         If you call self.thread.clear() it will clear objects for all workers!, be careful
         """
-        while not self.queue.empty(): self.queue.get()
-        #self.thread.clear()
-        
+        while not self.queue.empty():
+            self.queue.get()
+        # self.thread.clear()
+
     def purge(obj):
         nqueue = Queue.Queue()
-        while not self.queue.empty(): 
+        while not self.queue.empty():
             i = self.queue.get()
             if obj not in i:
                 nqueue.put(i)
         while not nqueue.empty():
             self.queue.put(nqueue.get())
-        
-    def isRunning(self): return self._running
-    def isFinished(self): return self.thread.isFinished()
-    def finished(self): return self.thread.finished()
-    def started(self): return self._running
-    def terminated(self): return self.thread.terminated()
-    def sleep(self,s): return self.thread.sleep(s)
-    
+
+    def isRunning(self):
+        return self._running
+
+    def isFinished(self):
+        return self.thread.isFinished()
+
+    def finished(self):
+        return self.thread.finished()
+
+    def started(self):
+        return self._running
+
+    def terminated(self):
+        return self.thread.terminated()
+
+    def sleep(self, s):
+        return self.thread.sleep(s)
