@@ -1,25 +1,25 @@
-##!/usr/bin/env python
+# !/usr/bin/env python
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -34,7 +34,7 @@ from taurus.qt.qtgui.panel.taurusconfigurationpanel import TaurusConfigurationPa
 
 
 class TaurusConfigurationDialog(Qt.QDialog):
-  
+
     def __init__(self, parent=None, designMode=False):
         Qt.QDialog.__init__(self, parent)
         self.setWindowTitle('TaurusConfigurationDialog')
@@ -45,22 +45,23 @@ class TaurusConfigurationDialog(Qt.QDialog):
         layout.setContentsMargins(0, 0, 0, 0)
         layout.addWidget(self._panel)
         self._panel._ui.pushButtonOk.setVisible(True)
-        self._panel._ui.pushButtonCancel.setVisible(True)        
-        self.connect(self._panel._ui.pushButtonOk, Qt.SIGNAL("clicked()"), self._onOk)
-        self.connect(self._panel._ui.pushButtonCancel, Qt.SIGNAL("clicked()"), self._onCancel)
+        self._panel._ui.pushButtonCancel.setVisible(True)
+        self._panel._ui.pushButtonOk.clicked.connect(self._onOk)
+        self._panel._ui.pushButtonCancel.clicked.connect(self._onCancel)
         self.adjustSize()
         self.show()
 
     def _onOk(self):
         self._panel._onOk()
         self._onCancel()
-          
+
     def _onCancel(self):
-        self.close()      
-            
+        self.close()
+
     def setModel(self, model):
-        self._panel.setModel(model)  
-             
+        self._panel.setModel(model)
+
+
 def main():
     import sys
     attr_name = sys.argv[1]
@@ -71,4 +72,4 @@ def main():
 
 if __name__ == "__main__":
     import sys
-    sys.exit(main())
\ No newline at end of file
+    sys.exit(main())
