@@ -2,24 +2,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -42,7 +42,7 @@ from taurus.core.util.wrap import wraps
 class TaurusMessageBox(Qt.QDialog):
     """A panel intended to display a taurus error.
     Example::
-    
+
         dev = taurus.Device("sys/tg_test/1")
         try:
             print dev.read_attribute("throw_exception")
@@ -53,18 +53,18 @@ class TaurusMessageBox(Qt.QDialog):
     You can show the error outside the exception handling code. If you do this,
     you should keep a record of the exception information as given by
     :func:`sys.exc_info`::
-    
+
         dev = taurus.Device("sys/tg_test/1")
         exc_info = None
         try:
             print dev.read_attribute("throw_exception")
         except PyTango.DevFailed, df:
             exc_info = sys.exc_info()
-        
+
         if exc_info:
             msgbox = TaurusMessageBox(*exc_info)
             msgbox.show()"""
-    
+
     def __init__(self, err_type=None, err_value=None, err_traceback=None,
                  parent=None, designMode=False):
         Qt.QDialog.__init__(self, parent)
@@ -76,62 +76,60 @@ class TaurusMessageBox(Qt.QDialog):
                                self, designMode)
         layout.setContentsMargins(0, 0, 0, 0)
         layout.addWidget(self._panel)
-        self.connect(self.panel().buttonBox(), Qt.SIGNAL("accepted()"),
-                     self.accept)
-        self.connect(self._panel, Qt.SIGNAL("toggledDetails(bool)"),
-                     self._onShowDetails)
-    
+        self.panel().buttonBox().accepted.connect(self.accept)
+        self._panel.toggledDetails.connect(self._onShowDetails)
+
     def _onShowDetails(self, show):
         self.adjustSize()
-    
+
     def panel(self):
         """Returns the :class:`taurus.qt.qtgui.panel.TaurusMessagePanel`.
-        
+
         :return: the internal panel
         :rtype: taurus.qt.qtgui.panel.TaurusMessagePanel"""
         return self._panel
-    
+
     def addButton(self, button, role=Qt.QDialogButtonBox.ActionRole):
         """Adds the given button with the given to the button box
-        
+
         :param button: the button to be added
         :type button: PyQt4.QtGui.QPushButton
         :param role: button role
         :type role: PyQt4.Qt.QDialogButtonBox.ButtonRole"""
         self.panel().addButton(button, role)
-    
+
     def setIconPixmap(self, pixmap):
         """Sets the icon to the dialog
-        
+
         :param pixmap: the icon pixmap
         :type pixmap: PyQt4.Qt.QPixmap"""
         self._panel.setIconPixmap(pixmap)
-    
+
     def setText(self, text):
         """Sets the text of the dialog
-        
+
         :param text: the new text
         :type text: str"""
         self._panel.setText(text)
-    
+
     def getText(self):
         """Returns the current text of this panel
-        
+
         :return: the text for this panel
         :rtype: str"""
         return self._panel.getText()
-    
+
     def setDetailedText(self, text):
         """Sets the detailed text of the dialog
-        
+
         :param text: the new text
         :type text: str"""
         self._panel.setDetailedText(text)
-    
+
     def setError(self, err_type=None, err_value=None, err_traceback=None):
         """Sets the exception object.
         Example usage::
-        
+
             dev = taurus.Device("sys/tg_test/1")
             exc_info = None
             msgbox = TaurusMessageBox()
@@ -139,11 +137,11 @@ class TaurusMessageBox(Qt.QDialog):
                 print dev.read_attribute("throw_exception")
             except PyTango.DevFailed, df:
                 exc_info = sys.exc_info()
-            
+
             if exc_info:
                 msgbox.setError(*exc_info)
                 msgbox.show()
-        
+
         :param err_type: the exception type of the exception being handled
                          (a class object)
         :type error: class object
@@ -152,19 +150,20 @@ class TaurusMessageBox(Qt.QDialog):
         :param err_traceback: a traceback object which encapsulates the call
                               stack at the point where the exception originally
                               occurred
-        :type err_traceback: traceback"""
+        :type err_traceback: TracebackType"""
         self._panel.setError(err_type, err_value, err_traceback)
 
 
 _PROTECT_MESSAGE_BOX = None
 
+
 def _ProtectMessageBox(err_type=None, err_value=None, err_traceback=None,
                        parent=None):
     global _PROTECT_MESSAGE_BOX
     box = _PROTECT_MESSAGE_BOX
     if box is None:
         _PROTECT_MESSAGE_BOX = box = TaurusMessageBox(err_type=err_type,
-            err_value=err_value, err_traceback=err_traceback, parent=parent)
+                                                      err_value=err_value, err_traceback=err_traceback, parent=parent)
         box.panel().setCheckBoxVisible(True)
     else:
         box.setError(err_type=err_type, err_value=err_value,
@@ -179,41 +178,43 @@ def protectTaurusMessageBox(fn):
     you which to protect against exceptions. The handle of the exception is to
     display a :class:`TaurusMessageBox` with the exception information.
     Example::
-    
+
         @protectTaurusMessgeBox
         def turnBeamOn(device_name):
             d = taurus.Device(device_name)
             d.TurnOn()
     """
-       
+
     @wraps(fn)
     def wrapped(*args, **kwargs):
         try:
             return fn(*args, **kwargs)
         except:
             msgbox = _ProtectMessageBox(*sys.exc_info())
-            if msgbox is None: return
+            if msgbox is None:
+                return
             msgbox.exec_()
     return wrapped
 
+
 class ProtectTaurusMessageBox(object):
-    """The idea of this class is to be used as a decorator on any method 
+    """The idea of this class is to be used as a decorator on any method
     you which to protect against exceptions. The handle of the exception is to
     display a :class:`TaurusMessageBox` with the exception information. The
     optional parameter title gives the window bar a customized title. The
     optional parameter msg allows you to give a customized message in the
     dialog. Example::
-    
+
         @ProtectTaurusMessgeBox(title="Error trying to turn the beam on")
         def turnBeamOn(device_name):
             d = taurus.Device(device_name)
             d.TurnOn()
     """
-    
+
     def __init__(self, title=None, msg=None):
         self._title = title
         self._msg = msg
-    
+
     def __call__(self, fn):
         @wraps(fn)
         def wrapped(*args, **kwargs):
@@ -221,28 +222,29 @@ class ProtectTaurusMessageBox(object):
                 return fn(*args, **kwargs)
             except:
                 msgbox = _ProtectMessageBox(*sys.exc_info())
-                if msgbox is None: return
+                if msgbox is None:
+                    return
                 if self._title is not None:
                     msgbox.setWindowTitle(self._title)
                 if self._msg is not None:
                     msgbox.setText(self._msg)
                 msgbox.exec_()
         return wrapped
-    
+
 
 class TaurusExceptHookMessageBox(BaseExceptHook):
     """A callable class that acts as an excepthook that displays an unhandled
     exception in a :class:`~taurus.qt.qtgui.dialog.TaurusMessageBox`.
-    
+
     :param hook_to: callable excepthook that will be called at the end of
                     this hook handling [default: None]
     :type hook_to: callable
     :param title: message box title [default: None meaning use exception value]
     :type name: str
     :param msg: message box text [default: None meaning use exception]"""
-    
+
     MSG_BOX = None
-    
+
     def __init__(self, hook_to=None, title=None, msg=None):
         BaseExceptHook.__init__(self, hook_to=hook_to)
         self._title = title
@@ -251,10 +253,10 @@ class TaurusExceptHookMessageBox(BaseExceptHook):
     def _getMessageBox(self, err_type=None, err_value=None, err_traceback=None,
                        parent=None):
         box = self.__class__.MSG_BOX
-        
+
         if box is None:
             self.__class__.MSG_BOX = box = TaurusMessageBox(err_type=err_type,
-                err_value=err_value, err_traceback=err_traceback, parent=parent)
+                                                            err_value=err_value, err_traceback=err_traceback, parent=parent)
             box.panel().setCheckBoxVisible(True)
         else:
             box.setError(err_type=err_type, err_value=err_value,
@@ -278,18 +280,23 @@ class TaurusExceptHookMessageBox(BaseExceptHook):
             msgbox.setText(self._msg)
         msgbox.exec_()
 
+
 class DemoException(Exception):
     pass
 
+
 def s1():
     return s2()
 
+
 def s2():
     return s3()
 
+
 def s3():
     raise DemoException("A demo exception occurred")
 
+
 def py_exc():
     try:
         s1()
@@ -297,6 +304,7 @@ def py_exc():
         msgbox = TaurusMessageBox(*sys.exc_info())
         msgbox.exec_()
 
+
 def tg_exc():
     import PyTango
     try:
@@ -306,6 +314,7 @@ def tg_exc():
         msgbox = TaurusMessageBox(*sys.exc_info())
         msgbox.exec_()
 
+
 def tg_serv_exc():
     import PyTango
     import taurus
@@ -319,6 +328,7 @@ def tg_serv_exc():
         msgbox = TaurusMessageBox(*sys.exc_info())
         msgbox.exec_()
 
+
 def py_tg_serv_exc():
     import PyTango
     try:
@@ -326,7 +336,8 @@ def py_tg_serv_exc():
                                        'A simple tango exception', 'right here')
     except PyTango.DevFailed, df1:
         try:
-            import traceback, StringIO
+            import traceback
+            import StringIO
             origin = StringIO.StringIO()
             traceback.print_stack(file=origin)
             origin.seek(0)
@@ -338,46 +349,48 @@ def py_tg_serv_exc():
             msgbox = TaurusMessageBox(*sys.exc_info())
             msgbox.exec_()
 
+
 def demo():
     """Message dialog"""
     panel = Qt.QWidget()
     layout = Qt.QVBoxLayout()
     panel.setLayout(layout)
-    
+
     m1 = Qt.QPushButton("Python exception")
     layout.addWidget(m1)
-    Qt.QObject.connect(m1, Qt.SIGNAL("clicked()"), py_exc)
+    m1.clicked.connect(py_exc)
     m2 = Qt.QPushButton("Tango exception")
     layout.addWidget(m2)
-    Qt.QObject.connect(m2, Qt.SIGNAL("clicked()"), tg_exc)
+    m2.clicked.connect(tg_exc)
     layout.addWidget(m2)
     m3 = Qt.QPushButton("Tango server exception")
     layout.addWidget(m3)
-    Qt.QObject.connect(m3, Qt.SIGNAL("clicked()"), tg_serv_exc)
+    m3.clicked.connect(tg_serv_exc)
     layout.addWidget(m3)
     m4 = Qt.QPushButton("Python tango server exception")
     layout.addWidget(m4)
-    Qt.QObject.connect(m4, Qt.SIGNAL("clicked()"), py_tg_serv_exc)
+    m4.clicked.connect(py_tg_serv_exc)
     layout.addWidget(m4)
 
     panel.show()
     return panel
-    
+
+
 def main():
     import taurus.qt.qtgui.application
 
     Application = taurus.qt.qtgui.application.TaurusApplication
-    
+
     app = Application.instance()
     owns_app = app is None
-    
+
     if owns_app:
         app = Qt.QApplication([])
         app.setApplicationName("Taurus message demo")
         app.setApplicationVersion("1.0")
 
     w = demo()
-    
+
     if owns_app:
         sys.exit(app.exec_())
     else:
@@ -385,4 +398,3 @@ def main():
 
 if __name__ == "__main__":
     main()
-    
