@@ -2,24 +2,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
+# This file is part of Taurus
 ##
-## http://taurus-scada.org
+# http://taurus-scada.org
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 ##
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
 ##
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -37,9 +37,7 @@ def demo():
     import sys
     import taurus.qt.qtgui.application
     import taurus.qt.qtgui.display
-    import taurus.qt.qtgui.resource
-
-    getPixmap = taurus.qt.qtgui.resource.getPixmap
+    from taurus.qt.qtgui.icon import getCachedPixmap
     Application = taurus.qt.qtgui.application.TaurusApplication
     QPixmapWidget = taurus.qt.qtgui.display.QPixmapWidget
 
@@ -87,7 +85,8 @@ def demo():
             panel_l.addWidget(display_panel, 1)
             panel_l.addWidget(control_panel, 0)
 
-            aspect_ratio_widget.addItems(["Ignore", "Keep", "Keep by expanding"])
+            aspect_ratio_widget.addItems(
+                ["Ignore", "Keep", "Keep by expanding"])
             transformation_widget.addItems(["Fast", "Smooth"])
             halign_widget.addItem("Left", Qt.QVariant(Qt.Qt.AlignLeft))
             halign_widget.addItem("Center", Qt.QVariant(Qt.Qt.AlignHCenter))
@@ -96,11 +95,11 @@ def demo():
             valign_widget.addItem("Center", Qt.QVariant(Qt.Qt.AlignVCenter))
             valign_widget.addItem("Bottom", Qt.QVariant(Qt.Qt.AlignBottom))
 
-            Qt.QObject.connect(pixmap_widget, Qt.SIGNAL("textChanged(const QString &)"), self.changePixmap)
-            Qt.QObject.connect(aspect_ratio_widget, Qt.SIGNAL("currentIndexChanged(int)"), self.changeAspectRatio)
-            Qt.QObject.connect(transformation_widget, Qt.SIGNAL("currentIndexChanged(int)"), self.changeTransformationMode)
-            Qt.QObject.connect(halign_widget, Qt.SIGNAL("currentIndexChanged(int)"), self.changeAlignment)
-            Qt.QObject.connect(valign_widget, Qt.SIGNAL("currentIndexChanged(int)"), self.changeAlignment)
+            pixmap_widget.textChanged.connect(self.changePixmap)
+            aspect_ratio_widget.currentIndexChanged.connect(self.changeAspectRatio)
+            transformation_widget.currentIndexChanged.connect(self.changeTransformationMode)
+            halign_widget.currentIndexChanged.connect(self.changeAlignment)
+            valign_widget.currentIndexChanged.connect(self.changeAlignment)
 
             self.w = w
             self.w_pixmap = pixmap_widget
@@ -109,14 +108,15 @@ def demo():
             self.w_halign = halign_widget
             self.w_valign = valign_widget
 
-            pixmap_widget.setText(":leds/images256/led_red_on.png")
+            name = "leds_images256:led_red_on.png"
+            pixmap_widget.setText(name)
             aspect_ratio_widget.setCurrentIndex(1)
             transformation_widget.setCurrentIndex(1)
             halign_widget.setCurrentIndex(0)
             valign_widget.setCurrentIndex(1)
 
         def changePixmap(self, name):
-            self.w.pixmap = getPixmap(name)
+            self.w.pixmap = getCachedPixmap(name)
 
         def changeAspectRatio(self, i):
             v = Qt.Qt.IgnoreAspectRatio
@@ -140,7 +140,7 @@ def demo():
             self.w.alignment = halign | valign
 
     panel = Qt.QWidget()
-    layout=Qt.QGridLayout()
+    layout = Qt.QGridLayout()
     panel.setLayout(layout)
     layout.setContentsMargins(M, M, M, M)
     layout.setSpacing(M)
@@ -152,6 +152,7 @@ def demo():
     else:
         return panel
 
+
 def main():
     return demo()
 
