@@ -2,24 +2,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -32,6 +32,7 @@ __docformat__ = 'restructuredtext'
 
 from taurus.external.qt import Qt
 
+
 def demo():
     import sys
     import taurus.qt.qtgui.application
@@ -39,17 +40,17 @@ def demo():
 
     Application = taurus.qt.qtgui.application.TaurusApplication
     TaurusLCD = taurus.qt.qtgui.display.TaurusLCD
-    
+
     app = Application.instance()
     owns_app = app is None
-    
+
     if owns_app:
         app = Application()
 
     M = 2
 
     class TaurusLCDTestPanel(Qt.QWidget):
-        
+
         def __init__(self, parent=None):
             Qt.QWidget.__init__(self, parent)
             panel_l = Qt.QVBoxLayout()
@@ -84,31 +85,31 @@ def demo():
 
             fg_widget.addItems(["value", "w_value", "none"])
             bg_widget.addItems(["quality", "state", "none"])
-            
-            Qt.QObject.connect(model_widget, Qt.SIGNAL("textChanged(const QString &)"), w.setModel)
-            Qt.QObject.connect(model_index_widget, Qt.SIGNAL("textChanged(const QString &)"), w.setModelIndex)
-            Qt.QObject.connect(fg_widget, Qt.SIGNAL("currentIndexChanged(const QString &)"), w.setFgRole)
-            Qt.QObject.connect(bg_widget, Qt.SIGNAL("currentIndexChanged(const QString &)"), w.setBgRole)
-            
+
+            model_widget.textChanged.connect(w.setModel)
+            model_index_widget.textChanged.connect(w.setModelIndex)
+            fg_widget.currentIndexChanged[str].connect(w.setFgRole)
+            bg_widget.currentIndexChanged[str].connect(w.setBgRole)
+
             model_widget.setText("sys/tg_test/1/double_scalar")
             fg_widget.setCurrentIndex(0)
             bg_widget.setCurrentIndex(0)
-            
+
             self.w_label = w
             self.w_model = model_widget
             self.w_model_index = model_index_widget
             self.w_fg = fg_widget
             self.w_bg = bg_widget
-    
+
     panel = Qt.QWidget()
-    layout=Qt.QGridLayout()
+    layout = Qt.QGridLayout()
     panel.setLayout(layout)
     layout.setContentsMargins(M, M, M, M)
     layout.setSpacing(M)
     p1 = TaurusLCDTestPanel()
     p1.w_model.setText("sys/tg_test/1/double_scalar")
     p2 = TaurusLCDTestPanel()
-    p2.w_model.setText("sys/tg_test/1/double_scalar?configuration=min_value")
+    p2.w_model.setText("sys/tg_test/1/double_scalar#min_value")
     p2.w_bg.setCurrentIndex(2)
     layout.addWidget(p1, 0, 0)
     layout.addWidget(p2, 0, 1)
@@ -120,9 +121,10 @@ def demo():
         sys.exit(app.exec_())
     else:
         return panel
-    
+
+
 def main():
     return demo()
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
