@@ -2,24 +2,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -32,6 +32,7 @@ __docformat__ = 'restructuredtext'
 
 from taurus.external.qt import Qt
 
+
 def demo():
     import sys
     import taurus.qt.qtgui.application
@@ -39,17 +40,17 @@ def demo():
 
     Application = taurus.qt.qtgui.application.TaurusApplication
     TaurusLed = taurus.qt.qtgui.display.TaurusLed
-    
+
     app = Application.instance()
     owns_app = app is None
-    
+
     if owns_app:
         app = Application()
 
     M = 2
 
     class TaurusLedTestPanel(Qt.QWidget):
-        
+
         def __init__(self, parent=None):
             Qt.QWidget.__init__(self, parent)
             panel_l = Qt.QVBoxLayout()
@@ -84,34 +85,35 @@ def demo():
             control_l.addRow("OFF color:", off_color_widget)
             panel_l.addWidget(display_panel, 1)
             panel_l.addWidget(control_panel, 0)
-            
-            fg_widget.addItems(["value", "w_value", "quality"])
-            colors = ["green", "blue", "orange", "red", "yellow", "magenta", "grenoble", "black"]
+
+            fg_widget.addItems(["rvalue", "wvalue", "quality"])
+            colors = ["green", "blue", "orange", "red",
+                      "yellow", "magenta", "grenoble", "black"]
             on_color_widget.addItems(colors)
             off_color_widget.addItems(colors)
-            
-            Qt.QObject.connect(inverted_widget, Qt.SIGNAL("toggled(bool)"), w.setLedInverted)
-            Qt.QObject.connect(model_widget, Qt.SIGNAL("textChanged(const QString &)"), w.setModel)
-            Qt.QObject.connect(fg_widget, Qt.SIGNAL("currentIndexChanged(const QString &)"), w.setFgRole)
-            Qt.QObject.connect(model_index_widget, Qt.SIGNAL("textChanged(const QString &)"), w.setModelIndex)
-            Qt.QObject.connect(on_color_widget, Qt.SIGNAL("currentIndexChanged(const QString &)"), w.setOnColor)
-            Qt.QObject.connect(off_color_widget, Qt.SIGNAL("currentIndexChanged(const QString &)"), w.setOffColor)
-            
+
+            inverted_widget.toggled.connect(w.setLedInverted)
+            model_widget.textChanged.connect(w.setModel)
+            fg_widget.currentIndexChanged[str].connect(w.setFgRole)
+            model_index_widget.textChanged.connect(w.setModelIndex)
+            on_color_widget.currentIndexChanged[str].connect(w.setOnColor)
+            off_color_widget.currentIndexChanged[str].connect(w.setOffColor)
+
             inverted_widget.setChecked(False)
             model_widget.setText("sys/tg_test/1/state")
             fg_widget.setCurrentIndex(0)
             on_color_widget.setCurrentIndex(0)
             off_color_widget.setCurrentIndex(7)
-            
+
             self.w_led = w
             self.w_model = model_widget
             self.w_fg = fg_widget
             self.w_model_index = model_index_widget
             self.w_on_color = on_color_widget
             self.w_off_color = off_color_widget
-            
+
     panel = Qt.QWidget()
-    layout=Qt.QGridLayout()
+    layout = Qt.QGridLayout()
     panel.setLayout(layout)
     layout.setContentsMargins(M, M, M, M)
     layout.setSpacing(M)
@@ -131,9 +133,10 @@ def demo():
         sys.exit(app.exec_())
     else:
         return panel
-    
+
+
 def main():
     return demo()
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
