@@ -2,24 +2,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -44,9 +44,9 @@ from taurus.qt.qtgui.base import TaurusConfigurationControllerHelper
 from taurus.qt.qtgui.base import updateLabelBackground
 
 _QT_PLUGIN_INFO = {
-    'module' : 'taurus.qt.qtgui.display',
-    'group' : 'Taurus Display',
-    'icon' : ":/designer/label.png",
+    'module': 'taurus.qt.qtgui.display',
+    'group': 'Taurus Display',
+    'icon': "designer:label.png",
 }
 
 TaurusModelType = TaurusElementType
@@ -54,7 +54,7 @@ EventType = TaurusEventType
 
 
 class TaurusLabelController(TaurusBaseController):
-    
+
     StyleSheetTemplate = "border-style: outset; border-width: 2px; border-color: {0}; {1}"
 
     def __init__(self, label):
@@ -71,7 +71,7 @@ class TaurusLabelController(TaurusBaseController):
             label.setFrameShape(Qt.QFrame.Box)
             label.setFrameShadow(Qt.QFrame.Raised)
             label.setLineWidth(1)
-    
+
     def label(self):
         return self.widget()
 
@@ -82,28 +82,17 @@ class TaurusLabelController(TaurusBaseController):
         label = self.label()
         ret = 'state' in (label.fgRole, label.bgRole)
         return ret
-    
+
     def _updateForeground(self, label):
-        fgRole, value = label.fgRole, ""
-        if fgRole == 'value':
-            value += self.getDisplayValue()
-        elif fgRole == 'w_value':
-            value += self.getDisplayValue(True)
-        elif fgRole == 'state':
-            stateObj = self.stateObj()
-            value += stateObj and stateObj.getDisplayValue() or label.getNoneValue()
-        elif fgRole == 'quality':
-            quality = self.quality()
-            if quality is None:
-                value += label.getNoneValue()
-            else:
-                value += str(quality)
-        elif fgRole in ('', 'none'):
+        fgRole, value = label.fgRole, ''
+
+        # handle special cases (that are not covered with fragment)
+        if fgRole.lower() == 'state':
+            value = self.state().name
+        elif fgRole.lower() in ('', 'none'):
             pass
         else:
-            label.setText("undef")
-            return
-        
+            value = label.getDisplayValue(fragmentName=fgRole)
         self._text = text = label.prefixText + value + label.suffixText
 
         # Checks that the display fits in the widget and sets it to "..." if
@@ -111,14 +100,12 @@ class TaurusLabelController(TaurusBaseController):
         self._trimmedText = self._shouldTrim(label, text)
         if self._trimmedText:
             text = "<a href='...'>...</a>"
-
         label.setText(text)
 
-    
     def _shouldTrim(self, label, text):
         if not label.autoTrim:
             return False
-        text = re.sub(self._trimPattern,'',text)
+        text = re.sub(self._trimPattern, '', text)
         font_metrics = Qt.QFontMetrics(label.font())
         size, textSize = label.size().width(), font_metrics.width(text)
         return textSize > size
@@ -128,12 +115,14 @@ class TaurusLabelController(TaurusBaseController):
             return
         toolTip = label.getFormatedToolTip()
         if self._trimmedText:
-            toolTip = u"<p><b>Value:</b> %s</p><hr>%s" % (unicode(self._text,errors='replace'), unicode(toolTip,errors='replace'))
+            toolTip = u"<p><b>Value:</b> %s</p><hr>%s" %\
+                      (unicode(self._text, errors='replace'),
+                       unicode(str(toolTip), errors='replace'))
         label.setToolTip(toolTip)
 
     _updateBackground = updateLabelBackground
 
-            
+
 class TaurusLabelControllerAttribute(TaurusScalarAttributeControllerHelper, TaurusLabelController):
 
     def __init__(self, label):
@@ -143,9 +132,10 @@ class TaurusLabelControllerAttribute(TaurusScalarAttributeControllerHelper, Taur
     def _setStyle(self):
         TaurusLabelController._setStyle(self)
         label = self.label()
-        label.setDynamicTextInteractionFlags(Qt.Qt.TextSelectableByMouse | Qt.Qt.LinksAccessibleByMouse)
+        label.setDynamicTextInteractionFlags(
+            Qt.Qt.TextSelectableByMouse | Qt.Qt.LinksAccessibleByMouse)
+
 
-        
 class TaurusLabelControllerConfiguration(TaurusConfigurationControllerHelper, TaurusLabelController):
 
     def __init__(self, label):
@@ -163,25 +153,25 @@ class TaurusLabelControllerConfiguration(TaurusConfigurationControllerHelper, Ta
 #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
 
 class TaurusLabelControllerDesignMode(object):
-    
+
     def _updateLength(self, lcd):
         lcd.setNumDigits(6)
-        
+
     def getDisplayValue(self, write=False):
         v = self.w_value()
         if not write:
             v = self.value()
         return "%6.2f" % v
-    
+
     def value(self):
         return 99.99
-    
+
     def w_value(self):
         return 0.0
-        
+
     def quality(self):
         return PyTango.AttrQuality.ATTR_VALID
-    
+
     def state(self):
         return PyTango.DevState.ON
 
@@ -190,7 +180,7 @@ class TaurusLabelControllerDesignMode(object):
 
 
 class TaurusLabelControllerAttributeDesignMode(TaurusLabelControllerDesignMode, TaurusLabelControllerAttribute):
-    
+
     def __init__(self, label):
         TaurusLabelControllerDesignMode.__init__(self)
         TaurusLabelControllerAttribute.__init__(self, label)
@@ -201,40 +191,43 @@ class TaurusLabelControllerConfigurationDesignMode(TaurusLabelControllerDesignMo
     def __init__(self, label):
         TaurusLabelControllerDesignMode.__init__(self)
         TaurusLabelControllerConfiguration.__init__(self, label)
-    
+
     def getDisplayValue(self, write=False):
         return "%6.2f" % -99.99
-        
+
     def _updateToolTip(self, lcd):
-        lcd.setToolTip("Some random configuration value for design purposes only")
+        lcd.setToolTip(
+            "Some random configuration value for design purposes only")
 
 
 _CONTROLLER_MAP = {
-                         None : None,
-      TaurusModelType.Unknown : None,
-    TaurusModelType.Attribute : TaurusLabelControllerAttribute,
-TaurusModelType.Configuration : TaurusLabelControllerConfiguration,
+    None: None,
+    TaurusModelType.Unknown: None,
+    TaurusModelType.Attribute: TaurusLabelControllerAttribute,
+    TaurusModelType.Configuration: TaurusLabelControllerConfiguration,
 }
 
 _DESIGNER_CONTROLLER_MAP = {
-                         None : TaurusLabelControllerAttributeDesignMode,
-      TaurusModelType.Unknown : TaurusLabelControllerAttributeDesignMode,
-    TaurusModelType.Attribute : TaurusLabelControllerAttributeDesignMode,
-TaurusModelType.Configuration : TaurusLabelControllerConfigurationDesignMode,
+    None: TaurusLabelControllerAttributeDesignMode,
+    TaurusModelType.Unknown: TaurusLabelControllerAttributeDesignMode,
+    TaurusModelType.Attribute: TaurusLabelControllerAttributeDesignMode,
+    TaurusModelType.Configuration: TaurusLabelControllerConfigurationDesignMode,
 }
 
 
 class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
-    
+
     DefaultPrefix = ''
     DefaultSuffix = ''
     DefaultBgRole = 'quality'
-    DefaultFgRole = 'value'
+    DefaultFgRole = 'rvalue'
     DefaultShowText = True
     DefaultModelIndex = None
     DefaultAutoTrim = True
     DefaultAlignment = Qt.Qt.AlignRight | Qt.Qt.AlignVCenter
 
+    _deprecatedRoles = dict(value='rvalue', w_value='wvalue')
+
     def __init__(self, parent=None, designMode=False):
         self._prefix = self.DefaultPrefix
         self._suffix = self.DefaultSuffix
@@ -251,11 +244,10 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
 
         self.setAlignment(self.DefaultAlignment)
 
-        self.connect(self, Qt.SIGNAL("linkActivated (const QString &)"), 
-                     self.showValueDialog)
+        self.linkActivated.connect(self.showValueDialog)
 
         # if we are in design mode there will be no events so we force the
-        # creation of a controller object 
+        # creation of a controller object
         if self._designMode:
             self.controllerUpdate()
 
@@ -263,24 +255,28 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
         ctrl_map = _CONTROLLER_MAP
         if self._designMode:
             ctrl_map = _DESIGNER_CONTROLLER_MAP
-            
+
         model_type = self.getModelType()
+        # ugly workaround to adapt TaurusLabel to tep14 without refactoring
+        # TODO: proper refactoring of TaurusValue to supress the Conf API
+        if model_type == TaurusModelType.Attribute and self.modelFragmentName:
+            model_type = TaurusModelType.Configuration
         ctrl_klass = ctrl_map.get(model_type, TaurusLabelController)
         return ctrl_klass
-    
+
     def controller(self):
         ctrl = self._controller
         # if there is a controller object and it is not the base controller...
         if ctrl is not None and not ctrl.__class__ == TaurusLabelController:
             return ctrl
-        
+
         # if there is a controller object and it is still the same class...
         ctrl_klass = self._calculate_controller_class()
         if ctrl_klass is None:
             return None
         elif ctrl.__class__ == ctrl_klass:
             return ctrl
-    
+
         self._controller = ctrl = ctrl_klass(self)
         return ctrl
 
@@ -288,37 +284,39 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
         ctrl = self.controller()
         if ctrl is not None:
             ctrl.update()
-    
+
     def showValueDialog(self, *args):
         ctrl = self.controller()
         if ctrl is not None:
             ctrl.showValueDialog(self)
 
-    def resizeEvent(self,event):
-    #    # recheck the display every time we resize to make sure the text should
-    #    # become trimmed or not
+    def resizeEvent(self, event):
+        #    # recheck the display every time we resize to make sure the text should
+        #    # become trimmed or not
         if not getattr(self, '_inResize', False):
             self._inResize = True
             self.controllerUpdate()
             self._inResize = False
         Qt.QLabel.resizeEvent(self, event)
-        
+
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
     # TaurusBaseWidget overwriting
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
-   
+
     def handleEvent(self, evt_src, evt_type, evt_value):
         ctrl = self.controller()
         if ctrl is not None:
             ctrl.handleEvent(evt_src, evt_type, evt_value)
-    
+
     def isReadOnly(self):
         return True
 
     def setModel(self, m):
-        #force to build another controller
+        # force to build another controller
         self._controller = None
         TaurusBaseWidget.setModel(self, m)
+        if self.modelFragmentName:
+            self.setFgRole(self.modelFragmentName)
 
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
     # QT property definition
@@ -329,7 +327,7 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
 
     def getModelIndex(self):
         return self._modelIndexStr
-    
+
     def setModelIndex(self, modelIndex):
         mi = str(modelIndex)
         if len(mi) == 0:
@@ -346,7 +344,7 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
             self._modelIndex = mi_value
         self._modelIndexStr = mi
         self.controllerUpdate()
-        
+
     def getModelMimeData(self):
         mimeData = TaurusBaseWidget.getModelMimeData(self)
         mimeData.setText(self.text())
@@ -357,7 +355,7 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
 
     def getBgRole(self):
         return self._bgRole
-    
+
     def setBgRole(self, bgRole):
         self._bgRole = str(bgRole).lower()
         self.controllerUpdate()
@@ -367,38 +365,43 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
 
     def getFgRole(self):
         return self._fgRole
-    
+
     def setFgRole(self, fgRole):
-        self._fgRole = str(fgRole).lower()
+        # warn about deprecated roles
+        role = self._deprecatedRoles.get(fgRole, fgRole)
+        if fgRole != role:
+            self.deprecated(rel='4.0', dep='setFgRole(%s)' % fgRole,
+                            alt='setFgRole(%s)' % role)
+        self._fgRole = str(role)
         self.controllerUpdate()
 
     def resetFgRole(self):
         self.setFgRole(self.DefaultFgRole)
-        
+
     def getPrefixText(self):
         return self._prefix
-    
-    def setPrefixText(self,prefix):
+
+    def setPrefixText(self, prefix):
         self._prefix = str(prefix)
         self.controllerUpdate()
 
     def resetPrefixText(self):
         self.setPrefixText(self.DefaultPrefix)
-        
+
     def getSuffixText(self):
         return self._suffix
-    
-    def setSuffixText(self,suffix):
+
+    def setSuffixText(self, suffix):
         self._suffix = str(suffix)
         self.controllerUpdate()
-    
+
     def resetSuffixText(self):
         self.setSuffixText(self.DefaultSuffix)
 
     def setAutoTrim(self, trim):
         self._autoTrim = trim
         self.controllerUpdate()
-        
+
     def setDynamicTextInteractionFlags(self, flags):
         if self.hasDynamicTextInteractionFlags():
             Qt.QLabel.setTextInteractionFlags(self, flags)
@@ -426,11 +429,11 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
         d.update(_QT_PLUGIN_INFO)
         return d
 
-    #: This property holds the unique URI string representing the model name 
-    #: with which this widget will get its data from. The convention used for 
+    #: This property holds the unique URI string representing the model name
+    #: with which this widget will get its data from. The convention used for
     #: the string can be found :ref:`here <model-concept>`.
-    #: 
-    #: In case the property :attr:`useParentModel` is set to True, the model 
+    #:
+    #: In case the property :attr:`useParentModel` is set to True, the model
     #: text must start with a '/' followed by the attribute name.
     #:
     #: **Access functions:**
@@ -443,7 +446,7 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
     model = Qt.pyqtProperty("QString", TaurusBaseWidget.getModel, setModel,
                             TaurusBaseWidget.resetModel)
 
-    #: This property holds whether or not this widget should search in the 
+    #: This property holds whether or not this widget should search in the
     #: widget hierarchy for a model prefix in a parent widget.
     #:
     #: **Access functions:**
@@ -453,7 +456,7 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
     #:     * :meth:`TaurusBaseWidget.resetUseParentModel`
     #:
     #: .. seealso:: :ref:`model-concept`
-    useParentModel = Qt.pyqtProperty("bool", TaurusBaseWidget.getUseParentModel, 
+    useParentModel = Qt.pyqtProperty("bool", TaurusBaseWidget.getUseParentModel,
                                      TaurusBaseWidget.setUseParentModel,
                                      TaurusBaseWidget.resetUseParentModel)
 
@@ -467,7 +470,8 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
     #:     * :meth:`TaurusLabel.resetModelIndex`
     #:
     #: .. seealso:: :ref:`model-concept`
-    modelIndex = Qt.pyqtProperty("QString", getModelIndex, setModelIndex, resetModelIndex)
+    modelIndex = Qt.pyqtProperty(
+        "QString", getModelIndex, setModelIndex, resetModelIndex)
 
     #: This property holds a prefix text
     #:
@@ -476,9 +480,9 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
     #:     * :meth:`TaurusLabel.getPrefixText`
     #:     * :meth:`TaurusLabel.setPrefixText`
     #:     * :meth:`TaurusLabel.resetPrefixText`
-    prefixText = Qt.pyqtProperty("QString", getPrefixText, setPrefixText, 
+    prefixText = Qt.pyqtProperty("QString", getPrefixText, setPrefixText,
                                  resetPrefixText, doc="prefix text")
-                                     
+
     #: This property holds a suffix text
     #:
     #: **Access functions:**
@@ -491,7 +495,7 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
 
     #: This property holds the foreground role (the text).
     #: Valid values are:
-    #:  
+    #:
     #:     #. ''/'None' - no value is displayed
     #:     #. 'value' - the value is displayed
     #:     #. 'w_value' - the write value is displayed
@@ -505,7 +509,7 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
     #:     * :meth:`TaurusLabel.resetFgRole`
     fgRole = Qt.pyqtProperty("QString", getFgRole, setFgRole,
                              resetFgRole, doc="foreground role")
-                                     
+
     #: This property holds the background role.
     #: Valid values are ''/'None', 'quality', 'state'
     #:
@@ -517,7 +521,7 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
     bgRole = Qt.pyqtProperty("QString", getBgRole, setBgRole,
                              resetBgRole, doc="background role")
 
-    #: This property holds the 
+    #: This property holds the
     #:
     #: **Access functions:**
     #:
@@ -526,19 +530,19 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
     #:     * :meth:`TaurusLabel.resetAutoTrim`
     autoTrim = Qt.pyqtProperty("bool", getAutoTrim, setAutoTrim,
                                resetAutoTrim, doc="auto trim text")
-    
-    #: This property holds the 
+
+    #: This property holds the
     #:
     #: **Access functions:**
     #:
     #:     * :meth:`TaurusLabel.isDragEnabled`
     #:     * :meth:`TaurusLabel.setDragEnabled`
     #:     * :meth:`TaurusLabel.resetDragEnabled`
-    dragEnabled = Qt.pyqtProperty("bool", TaurusBaseWidget.isDragEnabled, 
+    dragEnabled = Qt.pyqtProperty("bool", TaurusBaseWidget.isDragEnabled,
                                   TaurusBaseWidget.setDragEnabled,
-                                  TaurusBaseWidget.resetDragEnabled, 
+                                  TaurusBaseWidget.resetDragEnabled,
                                   doc="enable dragging")
-    
+
     #: Specifies how the label should interact with user input if it displays
     #: text.
     #:
@@ -549,39 +553,40 @@ class TaurusLabel(Qt.QLabel, TaurusBaseWidget):
     #:     * :meth:`TaurusLabel.resetTextInteractionFlags
     try:
         textInteractionFlags = Qt.pyqtProperty(Qt.Qt.TextInteractionFlag,
-                                   Qt.QLabel.textInteractionFlags,
-                                   setTextInteractionFlags,
-                                   resetTextInteractionFlags,
-                                   doc="Specifies how the label should interact with user input if it displays text.")
-    except TypeError: #Old PyQt4 version only accept strings for the type arg
+                                               Qt.QLabel.textInteractionFlags,
+                                               setTextInteractionFlags,
+                                               resetTextInteractionFlags,
+                                               doc="Specifies how the label should interact with user input if it displays text.")
+    except TypeError:  # Old PyQt4 version only accept strings for the type arg
         textInteractionFlags = Qt.pyqtProperty("int",
-                                   Qt.QLabel.textInteractionFlags,
-                                   setTextInteractionFlags,
-                                   resetTextInteractionFlags,
-                                   doc="Specifies how the label should interact with user input if it displays text.")
+                                               Qt.QLabel.textInteractionFlags,
+                                               setTextInteractionFlags,
+                                               resetTextInteractionFlags,
+                                               doc="Specifies how the label should interact with user input if it displays text.")
+
 
-    
 def demo():
     "Label"
     import demo.tauruslabeldemo
     return demo.tauruslabeldemo.main()
 
+
 def main():
     import sys
     import taurus.qt.qtgui.application
     Application = taurus.qt.qtgui.application.TaurusApplication
-    
+
     app = Application.instance()
     owns_app = app is None
-    
+
     if owns_app:
         import taurus.core.util.argparse
         parser = taurus.core.util.argparse.get_taurus_parser()
-        parser.usage = "%prog [options] <full_attribute_name(s) or full configuration_name(s)>"
-        app = Application(sys.argv, cmd_line_parser=parser, 
+        parser.usage = "%prog [options] <full_attribute_name(s)>"
+        app = Application(sys.argv, cmd_line_parser=parser,
                           app_name="Taurus label demo", app_version="1.0",
                           org_domain="Taurus", org_name="Tango community")
-        
+
     args = app.get_command_line_args()
 
     if len(args) == 0:
@@ -597,7 +602,7 @@ def main():
             label.model = model
             layout.addWidget(label)
     w.show()
-    
+
     if owns_app:
         sys.exit(app.exec_())
     else:
@@ -605,4 +610,3 @@ def main():
 
 if __name__ == '__main__':
     main()
-    
