@@ -3,24 +3,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -35,79 +35,72 @@ import operator
 
 from taurus.external.qt import Qt
 
-# Shame on me!!!!
-import PyTango
-
-State = PyTango.DevState
-DataFormat = PyTango.AttrDataFormat
-Quality = PyTango.AttrQuality
+from taurus.core import DataFormat, AttrQuality, DataType
+from taurus.core.tango import DevState
 
 from taurus.qt.qtgui.base import TaurusBaseWidget
 from qled import QLed
 
 _QT_PLUGIN_INFO = {
-    'module' : 'taurus.qt.qtgui.display',
-    'group' : 'Taurus Display',
-    'icon' : ":/designer/ledgreen.png",
+    'module': 'taurus.qt.qtgui.display',
+    'group': 'Taurus Display',
+    'icon': "designer:ledgreen.png",
 }
 
 
 class _TaurusLedController(object):
 
     #            key     status,     color, inTrouble
-    LedMap = {  True : (   True,    "green",    False),
-               False : (  False,    "black",    False),
-                None : (  False,    "black",     True) }
+    LedMap = {True: (True,    "green",    False),
+              False: (False,    "black",    False),
+              None: (False,    "black",     True)}
 
     LedQualityMap = {
-        Quality.ATTR_ALARM : (   True,   "orange",    False),
-     Quality.ATTR_CHANGING : (   True,     "blue",    False),
-      Quality.ATTR_INVALID : (   True,      "red",    False),
-        Quality.ATTR_VALID : (   True,    "green",    False),
-      Quality.ATTR_WARNING : (   True,   "orange",    False),
-                      None : (  False,    "black",     True) }
-    
+        AttrQuality.ATTR_ALARM: (True,   "orange",    False),
+        AttrQuality.ATTR_CHANGING: (True,     "blue",    False),
+        AttrQuality.ATTR_INVALID: (True,      "red",    False),
+        AttrQuality.ATTR_VALID: (True,    "green",    False),
+        AttrQuality.ATTR_WARNING: (True,   "orange",    False),
+        None: (False,    "black",     True)}
+
     def __init__(self, widget):
         self._widget = weakref.ref(widget)
 
     def widget(self):
         return self._widget()
-    
+
     def modelObj(self):
         return self.widget().getModelObj()
 
-    def valueObj(self):
-        modelObj = self.modelObj()
-        if modelObj is None: return None
-        return modelObj.getValueObj()
-    
     def value(self):
-        widget, obj = self.widget(), self.valueObj()
+        widget, obj = self.widget(), self.modelObj()
         fgRole = widget.fgRole
         value = None
-        if fgRole == 'value':
-            value = obj.value
-        elif fgRole == 'w_value':
-            value = obj.w_value
+        if fgRole == 'rvalue':
+            value = obj.rvalue
+        elif fgRole == 'wvalue':
+            value = obj.wvalue
         elif fgRole == 'quality':
             return obj.quality
-        
+
         # handle 1D and 2D values
-        if obj.data_format == DataFormat.SCALAR: return value
-        
+        if obj.data_format == DataFormat._0D:
+            return value
+
         idx = widget.getModelIndexValue()
         if idx is None or len(idx) == 0:
             return value
 
-        for i in idx: value = value[i]
+        for i in idx:
+            value = value[i]
         return value
-    
+
     def usePreferedColor(self, widget):
         return True
-    
+
     def handleEvent(self, evt_src, evt_type, evt_value):
         self.update()
-    
+
     def update(self):
         widget = self.widget()
 
@@ -149,7 +142,7 @@ class _TaurusLedController(object):
 
 
 class _TaurusLedControllerBool(_TaurusLedController):
-    
+
     def usePreferedColor(self, widget):
         # use prefered widget color if representing the boolean read or write
         # value. If representing the quality, use the quality map
@@ -157,30 +150,31 @@ class _TaurusLedControllerBool(_TaurusLedController):
 
 
 class _TaurusLedControllerState(_TaurusLedController):
-    
+
     #                key      status,       color, inTrouble
-    LedMap = {    State.ON : (   True,    "green",    False),
-                 State.OFF : (  False,    "black",    False),
-               State.CLOSE : (   True,    "white",    False),
-                State.OPEN : (   True,    "green",    False),
-              State.INSERT : (   True,    "green",    False),
-             State.EXTRACT : (   True,    "green",    False),
-              State.MOVING : (   True,     "blue",    False),
-             State.STANDBY : (   True,   "yellow",    False),
-               State.FAULT : (   True,      "red",    False),
-                State.INIT : (   True,   "yellow",    False),
-             State.RUNNING : (   True,     "blue",    False),
-               State.ALARM : (   True,   "orange",    False),
-             State.DISABLE : (   True,  "magenta",    False),
-             State.UNKNOWN : (  False,    "black",    False),
-                      None : (  False,    "black",     True) }
-    
+    LedMap = {DevState.ON: (True,    "green",    False),
+              DevState.OFF: (False,    "black",    False),
+              DevState.CLOSE: (True,    "white",    False),
+              DevState.OPEN: (True,    "green",    False),
+              DevState.INSERT: (True,    "green",    False),
+              DevState.EXTRACT: (True,    "green",    False),
+              DevState.MOVING: (True,     "blue",    False),
+              DevState.STANDBY: (True,   "yellow",    False),
+              DevState.FAULT: (True,      "red",    False),
+              DevState.INIT: (True,   "yellow",    False),
+              DevState.RUNNING: (True,     "blue",    False),
+              DevState.ALARM: (True,   "orange",    False),
+              DevState.DISABLE: (True,  "magenta",    False),
+              DevState.UNKNOWN: (False,    "black",    False),
+              None: (False,    "black",     True)}
+
     def usePreferedColor(self, widget):
         # never use prefered widget color. Use always the map
         return False
 
+
 class _TaurusLedControllerDesignMode(_TaurusLedController):
-    
+
     def _updateDisplay(self, widget):
         widget.ledStatus = True
         if widget.ledStatus:
@@ -188,21 +182,23 @@ class _TaurusLedControllerDesignMode(_TaurusLedController):
         else:
             widget.ledColor = widget.offColor
         widget.setAutoFillBackground(False)
-    
+
     def _updateToolTip(self, widget):
         widget.setToolTip("Design mode TaurusLed")
 
 
 class TaurusLed(QLed, TaurusBaseWidget):
-    """A widget designed to represent with a LED image the state of a device, 
+    """A widget designed to represent with a LED image the state of a device,
     the value of a boolean attribute or the quality of an attribute."""
-    
+
     DefaultModelIndex = None
-    DefaultFgRole = 'value'
+    DefaultFgRole = 'rvalue'
     DefaultOnColor = "green"
     DefaultOffColor = "black"
-    
-    def __init__(self, parent = None, designMode = False):
+
+    _deprecatedRoles = dict(value='rvalue', w_value='wvalue')
+
+    def __init__(self, parent=None, designMode=False):
         name = self.__class__.__name__
         self._designMode = designMode
         self._modelIndex = self.DefaultModelIndex
@@ -213,15 +209,15 @@ class TaurusLed(QLed, TaurusBaseWidget):
         self._controller = None
         self.call__init__wo_kw(QLed, parent)
         self.call__init__(TaurusBaseWidget, name, designMode=designMode)
-        
+
         # if we are in design mode there will be no events so we force the
-        # creation of a controller object 
+        # creation of a controller object
         if self._designMode:
             self.controller().update()
-            
+
     def _calculate_controller_class(self):
         model = self.getModelObj()
-        
+
         klass = _TaurusLedController
         if self._designMode:
             klass = _TaurusLedControllerDesignMode
@@ -229,7 +225,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
             klass = _TaurusLedController
         elif model.isBoolean():
             klass = _TaurusLedControllerBool
-        elif model.isState():
+        elif model.type == DataType.DevState:
             klass = _TaurusLedControllerState
         return klass
 
@@ -238,50 +234,54 @@ class TaurusLed(QLed, TaurusBaseWidget):
         # if there is a controller object and it is not the base controller...
         if ctrl is not None and not ctrl.__class__ == _TaurusLedController:
             return ctrl
-        
+
         # if there is a controller object and it is still the same class...
         ctrl_klass = self._calculate_controller_class()
         if ctrl is not None and ctrl.__class__ == ctrl_klass:
             return ctrl
-    
+
         self._controller = ctrl = ctrl_klass(self)
         return ctrl
-    
+
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
     # TaurusBaseWidget overwriting
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
-   
+
     def handleEvent(self, evt_src, evt_type, evt_value):
         self.controller().handleEvent(evt_src, evt_type, evt_value)
-    
+
     def isReadOnly(self):
         return True
 
     def setModel(self, m):
-        #force to build another controller
+        # force to build another controller
         self._controller = None
         TaurusBaseWidget.setModel(self, m)
 
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
     # QT property definition
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
-    
+
     def getFgRole(self):
         return self._fgRole
-    
+
     def setFgRole(self, fgRole):
-        self._fgRole = str(fgRole).lower()
+        role = self._deprecatedRoles.get(fgRole, fgRole)
+        if fgRole != role:
+            self.deprecated(rel='4.0', dep='setFgRole(%s)' % fgRole,
+                            alt='setFgRole(%s)' % role)
+        self._fgRole = str(role)
         self.controller().update()
 
     def resetFgRole(self):
         self.setFgRole(self.DefaultFgRole)
-        
+
     def getOnColor(self):
         """Returns the preferred led on color
         :return: led on color
         :rtype: str"""
         return self._onColor
-        
+
     def setOnColor(self, color):
         """Sets the preferred led on color
         :param status: the new on color
@@ -291,7 +291,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
             raise Exception("Invalid color '%s'" % color)
         self._onColor = color
         self.controller().update()
-    
+
     def resetOnColor(self):
         """Resets the preferred led on color"""
         self.setOnColor(self.DefaultOnColor)
@@ -301,7 +301,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
         :return: led off color
         :rtype: str"""
         return self._offColor
-        
+
     def setOffColor(self, color):
         """Sets the preferred led off color
         :param status: the new off color
@@ -311,7 +311,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
             raise Exception("Invalid color '%s'" % color)
         self._offColor = color
         self.controller().update()
-    
+
     def resetOffColor(self):
         """Resets the preferred led color"""
         self.setOffColor(self.DefaultOffColor)
@@ -321,7 +321,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
 
     def getModelIndex(self):
         return self._modelIndexStr
-    
+
     def setModelIndex(self, modelIndex):
         mi = str(modelIndex)
         if len(mi) == 0:
@@ -348,11 +348,11 @@ class TaurusLed(QLed, TaurusBaseWidget):
         d.update(_QT_PLUGIN_INFO)
         return d
 
-    #: This property holds the unique URI string representing the model name 
-    #: with which this widget will get its data from. The convention used for 
+    #: This property holds the unique URI string representing the model name
+    #: with which this widget will get its data from. The convention used for
     #: the string can be found :ref:`here <model-concept>`.
-    #: 
-    #: In case the property :attr:`useParentModel` is set to True, the model 
+    #:
+    #: In case the property :attr:`useParentModel` is set to True, the model
     #: text must start with a '/' followed by the attribute name.
     #:
     #: **Access functions:**
@@ -365,7 +365,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
     model = Qt.pyqtProperty("QString", TaurusBaseWidget.getModel, setModel,
                             TaurusBaseWidget.resetModel)
 
-    #: This property holds whether or not this widget should search in the 
+    #: This property holds whether or not this widget should search in the
     #: widget hierarchy for a model prefix in a parent widget.
     #:
     #: **Access functions:**
@@ -375,7 +375,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
     #:     * :meth:`TaurusBaseWidget.resetUseParentModel`
     #:
     #: .. seealso:: :ref:`model-concept`
-    useParentModel = Qt.pyqtProperty("bool", TaurusBaseWidget.getUseParentModel, 
+    useParentModel = Qt.pyqtProperty("bool", TaurusBaseWidget.getUseParentModel,
                                      TaurusBaseWidget.setUseParentModel,
                                      TaurusBaseWidget.resetUseParentModel)
 
@@ -394,7 +394,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
 
     #: This property holds the foreground role.
     #: Valid values are:
-    #:  
+    #:
     #:     #. 'value' - the value is used
     #:     #. 'w_value' - the write value is used
     #:     #. 'quality' - the quality is used
@@ -406,7 +406,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
     #:     * :meth:`TaurusLed.resetFgRole`
     fgRole = Qt.pyqtProperty("QString", getFgRole, setFgRole,
                              resetFgRole, doc="foreground role")
-                             
+
     #: This property holds the preferred led color
     #: This value is used for the cases where the model value does not contain
     #: enough information to distinguish between different On colors.
@@ -420,7 +420,7 @@ class TaurusLed(QLed, TaurusBaseWidget):
     #:     * :meth:`TaurusLed.setOnColor`
     #:     * :meth:`TaurusLed.resetOnColor`
     onColor = Qt.pyqtProperty("QString", getOnColor, setOnColor, resetOnColor,
-                               doc="preferred led On color")
+                              doc="preferred led On color")
 
     #: This property holds the preferred led color
     #: This value is used for the cases where the model value does not contain
@@ -437,23 +437,25 @@ class TaurusLed(QLed, TaurusBaseWidget):
     offColor = Qt.pyqtProperty("QString", getOffColor, setOffColor, resetOffColor,
                                doc="preferred led Off color")
 
+
 def demo():
     "Led"
     import demo.taurusleddemo
     return demo.taurusleddemo.main()
-    
+
+
 def main():
     import sys
     import taurus.qt.qtgui.application
     Application = taurus.qt.qtgui.application.TaurusApplication
-    
+
     app = Application.instance()
     owns_app = app is None
-    
+
     if owns_app:
         import taurus.core.util.argparse
         parser = taurus.core.util.argparse.get_taurus_parser()
-        parser.usage = "%prog [options] <full_attribute_name(s) or full configuration_name(s)>"
+        parser.usage = "%prog [options] <full_attribute_name(s)>"
         app = Application(sys.argv, cmd_line_parser=parser,
                           app_name="Taurus led demo", app_version="1.0",
                           org_domain="Taurus", org_name="Tango community")
@@ -473,7 +475,7 @@ def main():
             led.model = model
             layout.addWidget(led)
     w.show()
-    
+
     if owns_app:
         sys.exit(app.exec_())
     else:
