@@ -2,24 +2,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
+# This file is part of Taurus
 ##
-## http://taurus-scada.org
+# http://taurus-scada.org
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 ##
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
 ##
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -36,23 +36,22 @@ from taurus.qt.qtgui.base import TaurusBaseWritableWidget
 class TaurusValueCheckBox(Qt.QCheckBox, TaurusBaseWritableWidget):
     """A QCheckBox connected to a boolean writable attribute model"""
 
-    __pyqtSignals__ = ("modelChanged(const QString &)",)
-
-    def __init__(self, qt_parent = None, designMode = False):
+    def __init__(self, qt_parent=None, designMode=False):
         name = "TaurusValueCheckBox"
         self.call__init__wo_kw(Qt.QCheckBox, qt_parent)
-        self.call__init__(TaurusBaseWritableWidget, name, designMode=designMode)
+        self.call__init__(TaurusBaseWritableWidget,
+                          name, designMode=designMode)
 
         self.setObjectName(name)
         self.updateStyle()
-        self.connect(self, Qt.SIGNAL('stateChanged(int)'),self.valueChanged)
+        self.stateChanged.connect(self.notifyValueChanged)
 
     def keyPressEvent(self, event):
         if event.key() in (Qt.Qt.Key_Return, Qt.Qt.Key_Enter):
             self.writeValue()
             event.accept()
         else:
-            Qt.QCheckBox.keyPressEvent(self,event)
+            Qt.QCheckBox.keyPressEvent(self, event)
             event.ignore()
 
     def minimumSizeHint(self):
@@ -72,14 +71,15 @@ class TaurusValueCheckBox(Qt.QCheckBox, TaurusBaseWritableWidget):
                 self.setText('----')
         else:
             self.setText('')
-        #Update pending operations style
+        # Update pending operations style
         if self.hasPendingOperations():
             txt = str(self.text()).strip()
             if len(txt) == 0:
                 self.setText("!")
             self.setStyleSheet('TaurusValueCheckBox {color: blue;}')
         else:
-            if str(self.text()) == "!": self.setText(" ")
+            if str(self.text()) == "!":
+                self.setText(" ")
             self.setStyleSheet('TaurusValueCheckBox {}')
         self.update()
 
@@ -93,7 +93,7 @@ class TaurusValueCheckBox(Qt.QCheckBox, TaurusBaseWritableWidget):
     def getQtDesignerPluginInfo(cls):
         ret = TaurusBaseWritableWidget.getQtDesignerPluginInfo()
         ret['module'] = 'taurus.qt.qtgui.input'
-        ret['icon'] = ":/designer/checkbox.png"
+        ret['icon'] = "designer:checkbox.png"
         return ret
 
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
