@@ -1,24 +1,24 @@
 #!/usr/bin/env python
 #############################################################################
 ##
-## This file is part of Taurus
+# This file is part of Taurus
 ##
-## http://taurus-scada.org
+# http://taurus-scada.org
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 ##
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
 ##
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -41,15 +41,15 @@ class TaurusFormTest(GenericWidgetTestCase, unittest.TestCase):
                   ['sys/tg_test/1/wave'],
                   [],
                   '',
-                  ['eval://1'],
+                  ['eval:1'],
                   None,
                   ['sys/tg_test/1/%s' % a for a in (
                    'short_scalar', 'double_array',
                    'uchar_image_ro', 'string_spectrum',
                    'no_value', 'throw_exception')],
                   [''],
-                  'sys/tg_test/1,eval://1',
-                  'sys/tg_test/1/short_image eval://rand(16)',
+                  'sys/tg_test/1,eval:1',
+                  'sys/tg_test/1/short_image eval:rand(16)',
                   [None]
                   ]
 
@@ -65,7 +65,6 @@ class TaurusAttrFormTest(GenericWidgetTestCase, unittest.TestCase):
     modelnames = ['sys/tg_test/1', None]
 
 
-
 # if __name__ == "__main__":
 #     unittest.main()
 #    suite = unittest.defaultTestLoader.loadTestsFromTestCase(TaurusFormTest)
