@@ -2,24 +2,24 @@
 
 #############################################################################
 ##
-## This file is part of Taurus
-## 
-## http://taurus-scada.org
+# This file is part of Taurus
 ##
-## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
-## Taurus is free software: you can redistribute it and/or modify
-## it under the terms of the GNU Lesser General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-## 
-## Taurus is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU Lesser General Public License for more details.
-## 
-## You should have received a copy of the GNU Lesser General Public License
-## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
+# http://taurus-scada.org
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Taurus is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Taurus is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
@@ -32,7 +32,6 @@ __docformat__ = 'restructuredtext'
 from taurus.core.util.log import Logger
 from taurus.core.util.singleton import Singleton
 from taurus.external.qt import Qt
-from taurus.qt.qtgui.resource import getThemeIcon
 
 import taurusaction
 
@@ -49,7 +48,7 @@ class ActionFactory(Singleton, Logger):
         self.call__init__(Logger, 'ActionFactory')
         self.actions = self.__getActions()
         self.menus = self.__getMenus()
-    
+
     def __getClasses(self, super_class):
         ret = {}
         klass_type = type(super_class)
@@ -60,18 +59,18 @@ class ActionFactory(Singleton, Logger):
             if (type(klass) == klass_type and issubclass(klass, super_class)):
                 ret[klass.menuID] = klass
         return ret
-    
+
     def __getActions(self):
         """Calculates the map of existing action classes"""
         return self.__getClasses(taurusaction.TaurusAction)
 
     def __getMenus(self):
-        """Calculates the map of existing menu classes""" 
+        """Calculates the map of existing menu classes"""
         return self.__getClasses(taurusaction.TaurusMenu)
 
     def getActions(self):
         return self.actions
-    
+
     def getMenus(self):
         return self.menus
 
@@ -86,29 +85,29 @@ class ActionFactory(Singleton, Logger):
         doc = xml.dom.minidom.parseString(data)
         m_node = doc.childNodes[0]
         return self.buildMenu(widget, m_node)
-    
+
     def buildAction(self, widget, a_node):
         if not a_node.hasAttribute('class'):
             return None
-        
+
         id = a_node.getAttribute('class')
         action = self.getNewAction(widget, id)
-        
+
         # if node has alternative label, display it instead
         if a_node.hasAttribute('label'):
             action.setText(a_node.getAttribute('label'))
-            
+
         if a_node.hasAttribute('checkable'):
             action.setCheckable(bool(a_node.getAttribute('checkable')))
-        
+
         if a_node.hasAttribute('icon'):
             icon = a_node.getAttribute('icon')
-            #TODO
-            #action.setIcon(icon)
+            # TODO
+            # action.setIcon(icon)
         return action
-    
+
     def buildMenu(self, widget, m_node):
-        menu = None 
+        menu = None
         if m_node.hasAttribute('class'):
             klass = self.menus.get(m_node.getAttribute('class'))
             if klass is None:
@@ -118,21 +117,21 @@ class ActionFactory(Singleton, Logger):
             menu = taurusaction.TaurusMenu(widget)
             menu.buildFromXML(m_node)
         return menu
-    
+
     def createAction(self, parent, text, shortcut=None, icon=None, tip=None,
                      toggled=None, triggered=None, data=None,
                      context=Qt.Qt.WindowShortcut):
         """Create a QAction"""
         action = Qt.QAction(text, parent)
         if triggered is not None:
-            parent.connect(action, Qt.SIGNAL("triggered()"), triggered)
+            action.triggered.connect(triggered)
         if toggled is not None:
-            parent.connect(action, Qt.SIGNAL("toggled(bool)"), toggled)
+            action.toggled.connect(toggled)
             action.setCheckable(True)
         if icon is not None:
             if isinstance(icon, (str, unicode)):
-                icon = getThemeIcon(icon)
-            action.setIcon( icon )
+                icon = Qt.QIcon.fromTheme(icon)
+            action.setIcon(icon)
         if shortcut is not None:
             action.setShortcut(shortcut)
         if tip is not None:
@@ -140,8 +139,8 @@ class ActionFactory(Singleton, Logger):
             action.setStatusTip(tip)
         if data is not None:
             action.setData(data)
-        #TODO: Hard-code all shortcuts and choose context=Qt.WidgetShortcut
+        # TODO: Hard-code all shortcuts and choose context=Qt.WidgetShortcut
         # (this will avoid calling shortcuts from another dockwidget
         #  since the context thing doesn't work quite well with these widgets)
         action.setShortcutContext(context)
-        return action
\ No newline at end of file
+        return action
